@@ -18,6 +18,9 @@ ccache -M 2.0G
 # export CCACHE_LOGFILE=/tmp/cache.debug
 ccache -z
 
+# To make ccache work properly with precompiled headers
+ccache --set-config sloppiness=pch_defines,time_macros,include_file_mtime,include_file_ctime
+
 ##############################
 # Variables for output styling
 ##############################
@@ -67,6 +70,12 @@ if [[ ${WITH_GRASS7} == "ON" || ${WITH_GRASS8} == "ON" ]]; then
   )
 fi
 
+if [[ ${BUILD_WITH_QT6} = "ON" ]]; then
+  CMAKE_EXTRA_ARGS+=(
+    "-DUSE_ALTERNATE_LINKER=mold"
+  )
+fi
+
 cmake \
  -GNinja \
  -DCMAKE_BUILD_TYPE=${BUILD_TYPE} \
@@ -81,7 +90,6 @@ cmake \
  -DWITH_GRASS7=${WITH_GRASS7} \
  -DWITH_GRASS8=${WITH_GRASS8} \
  -DWITH_GRASS_PLUGIN=${WITH_GRASS8} \
- -DSUPPRESS_QT_WARNINGS=ON \
  -DENABLE_TESTS=ON \
  -DENABLE_MODELTEST=${WITH_QT5} \
  -DENABLE_PGTEST=${WITH_QT5} \
@@ -89,6 +97,7 @@ cmake \
  -DENABLE_MSSQLTEST=${WITH_QT5} \
  -DENABLE_HANATEST=${WITH_QT5} \
  -DENABLE_ORACLETEST=${WITH_QT5} \
+ -DENABLE_UNITY_BUILDS=${ENABLE_UNITY_BUILDS} \
  -DPUSH_TO_CDASH=${PUSH_TO_CDASH} \
  -DWITH_HANA=ON \
  -DWITH_QGIS_PROCESS=ON \
@@ -105,8 +114,8 @@ cmake \
  -DWITH_QTWEBKIT=${WITH_QT5} \
  -DWITH_QTWEBENGINE=${WITH_QTWEBENGINE} \
  -DWITH_PDF4QT=${WITH_PDF4QT} \
- -DORACLE_INCLUDEDIR=/instantclient_19_9/sdk/include/ \
- -DORACLE_LIBDIR=/instantclient_19_9/ \
+ -DORACLE_INCLUDEDIR=/instantclient_21_16/sdk/include/ \
+ -DORACLE_LIBDIR=/instantclient_21_16/ \
  -DDISABLE_DEPRECATED=ON \
  -DPYTHON_TEST_WRAPPER="timeout -sSIGSEGV 55s" \
  -DCXX_EXTRA_FLAGS="${CLANG_WARNINGS}" \
