@@ -14,14 +14,11 @@
  ***************************************************************************/
 
 #include "qgs3dmapsettings.h"
+#include "moc_qgs3dmapsettings.cpp"
 
+#include "qgs3d.h"
 #include "qgs3dutils.h"
-#include "qgsflatterraingenerator.h"
-#include "qgsdemterraingenerator.h"
-#include "qgsmeshterraingenerator.h"
-#include "qgsonlineterraingenerator.h"
 #include "qgsprojectviewsettings.h"
-#include "qgsquantizedmeshterraingenerator.h"
 #include "qgsprojectelevationproperties.h"
 #include "qgsterrainprovider.h"
 #include "qgslightsource.h"
@@ -32,6 +29,9 @@
 #include "qgs3drendercontext.h"
 #include "qgsthreadingutils.h"
 #include "qgsmaplayerlistutils_p.h"
+#include "qgsabstractterrainsettings.h"
+#include "qgsflatterrainsettings.h"
+#include "qgs3dterrainregistry.h"
 
 #include <QDomDocument>
 #include <QDomElement>
@@ -40,11 +40,11 @@
 Qgs3DMapSettings::Qgs3DMapSettings()
   : QObject( nullptr )
 {
-  connect( this, &Qgs3DMapSettings::settingsChanged, [&]()
-  {
+  connect( this, &Qgs3DMapSettings::settingsChanged, [&]() {
     QgsProject::instance()->setDirty();
   } );
   connectChangedSignalsToSettingsChanged();
+  mTerrainSettings = std::make_unique<QgsFlatTerrainSettings>();
 }
 
 Qgs3DMapSettings::Qgs3DMapSettings( const Qgs3DMapSettings &other )
@@ -54,12 +54,6 @@ Qgs3DMapSettings::Qgs3DMapSettings( const Qgs3DMapSettings &other )
   , mCrs( other.mCrs )
   , mBackgroundColor( other.mBackgroundColor )
   , mSelectionColor( other.mSelectionColor )
-  , mTerrainVerticalScale( other.mTerrainVerticalScale )
-  , mTerrainGenerator( other.mTerrainGenerator ? other.mTerrainGenerator->clone() : nullptr )
-  , mMapTileResolution( other.mMapTileResolution )
-  , mMaxTerrainScreenError( other.mMaxTerrainScreenError )
-  , mMaxTerrainGroundError( other.mMaxTerrainGroundError )
-  , mTerrainElevationOffset( other.mTerrainElevationOffset )
   , mTerrainShadingEnabled( other.mTerrainShadingEnabled )
   , mTerrainShadingMaterial( other.mTerrainShadingMaterial )
   , mTerrainMapTheme( other.mTerrainMapTheme )
@@ -69,6 +63,8 @@ Qgs3DMapSettings::Qgs3DMapSettings( const Qgs3DMapSettings &other )
   , mShowCameraRotationCenter( other.mShowCameraRotationCenter )
   , mShowLightSources( other.mShowLightSources )
   , mShowLabels( other.mShowLabels )
+  , mStopUpdates( other.mStopUpdates )
+  , mShowDebugPanel( other.mShowDebugPanel )
   , mFieldOfView( other.mFieldOfView )
   , mProjectionType( other.mProjectionType )
   , mCameraNavigationMode( other.mCameraNavigationMode )
@@ -101,14 +97,15 @@ Qgs3DMapSettings::Qgs3DMapSettings( const Qgs3DMapSettings &other )
   , mExtent( other.mExtent )
   , mShowExtentIn2DView( other.mShowExtentIn2DView )
 {
+  setTerrainSettings( other.mTerrainSettings ? other.mTerrainSettings->clone() : new QgsFlatTerrainSettings() );
+
   for ( QgsLightSource *source : std::as_const( other.mLightSources ) )
   {
     if ( source )
       mLightSources << source->clone();
   }
 
-  connect( this, &Qgs3DMapSettings::settingsChanged, [&]()
-  {
+  connect( this, &Qgs3DMapSettings::settingsChanged, [&]() {
     QgsProject::instance()->setDirty();
   } );
   connectChangedSignalsToSettingsChanged();
@@ -126,18 +123,20 @@ void Qgs3DMapSettings::readXml( const QDomElement &elem, const QgsReadWriteConte
   QgsProjectDirtyBlocker blocker( QgsProject::instance() );
   QDomElement elemOrigin = elem.firstChildElement( QStringLiteral( "origin" ) );
   mOrigin = QgsVector3D(
-              elemOrigin.attribute( QStringLiteral( "x" ) ).toDouble(),
-              elemOrigin.attribute( QStringLiteral( "y" ) ).toDouble(),
-              elemOrigin.attribute( QStringLiteral( "z" ) ).toDouble() );
+    elemOrigin.attribute( QStringLiteral( "x" ) ).toDouble(),
+    elemOrigin.attribute( QStringLiteral( "y" ) ).toDouble(),
+    elemOrigin.attribute( QStringLiteral( "z" ) ).toDouble()
+  );
 
   QDomElement elemExtent = elem.firstChildElement( QStringLiteral( "extent" ) );
   if ( !elemExtent.isNull() )
   {
     mExtent = QgsRectangle(
-                elemExtent.attribute( QStringLiteral( "xMin" ) ).toDouble(),
-                elemExtent.attribute( QStringLiteral( "yMin" ) ).toDouble(),
-                elemExtent.attribute( QStringLiteral( "xMax" ) ).toDouble(),
-                elemExtent.attribute( QStringLiteral( "yMax" ) ).toDouble() );
+      elemExtent.attribute( QStringLiteral( "xMin" ) ).toDouble(),
+      elemExtent.attribute( QStringLiteral( "yMin" ) ).toDouble(),
+      elemExtent.attribute( QStringLiteral( "xMax" ) ).toDouble(),
+      elemExtent.attribute( QStringLiteral( "yMax" ) ).toDouble()
+    );
 
     mShowExtentIn2DView = elemExtent.attribute( QStringLiteral( "showIn2dView" ), QStringLiteral( "0" ) ).toInt();
   }
@@ -150,7 +149,7 @@ void Qgs3DMapSettings::readXml( const QDomElement &elem, const QgsReadWriteConte
   if ( !elemCamera.isNull() )
   {
     mFieldOfView = elemCamera.attribute( QStringLiteral( "field-of-view" ), QStringLiteral( "45" ) ).toFloat();
-    mProjectionType = static_cast< Qt3DRender::QCameraLens::ProjectionType >( elemCamera.attribute( QStringLiteral( "projection-type" ), QStringLiteral( "1" ) ).toInt() );
+    mProjectionType = static_cast<Qt3DRender::QCameraLens::ProjectionType>( elemCamera.attribute( QStringLiteral( "projection-type" ), QStringLiteral( "1" ) ).toInt() );
     QString cameraNavigationMode = elemCamera.attribute( QStringLiteral( "camera-navigation-mode" ), QStringLiteral( "basic-navigation" ) );
     if ( cameraNavigationMode == QLatin1String( "terrain-based-navigation" ) )
       mCameraNavigationMode = Qgis::NavigationMode::TerrainBased;
@@ -171,12 +170,7 @@ void Qgs3DMapSettings::readXml( const QDomElement &elem, const QgsReadWriteConte
 
   QDomElement elemTerrain = elem.firstChildElement( QStringLiteral( "terrain" ) );
   mTerrainRenderingEnabled = elemTerrain.attribute( QStringLiteral( "terrain-rendering-enabled" ), QStringLiteral( "1" ) ).toInt();
-  mTerrainVerticalScale = elemTerrain.attribute( QStringLiteral( "exaggeration" ), QStringLiteral( "1" ) ).toFloat();
-  mMapTileResolution = elemTerrain.attribute( QStringLiteral( "texture-size" ), QStringLiteral( "512" ) ).toInt();
-  mMaxTerrainScreenError = elemTerrain.attribute( QStringLiteral( "max-terrain-error" ), QStringLiteral( "3" ) ).toFloat();
-  mMaxTerrainGroundError = elemTerrain.attribute( QStringLiteral( "max-ground-error" ), QStringLiteral( "1" ) ).toFloat();
   mTerrainShadingEnabled = elemTerrain.attribute( QStringLiteral( "shading-enabled" ), QStringLiteral( "0" ) ).toInt();
-  mTerrainElevationOffset = elemTerrain.attribute( QStringLiteral( "elevation-offset" ), QStringLiteral( "0.0" ) ).toFloat();
 
   QDomElement elemTerrainShadingMaterial = elemTerrain.firstChildElement( QStringLiteral( "shading-material" ) );
   if ( !elemTerrainShadingMaterial.isNull() )
@@ -206,7 +200,7 @@ void Qgs3DMapSettings::readXml( const QDomElement &elem, const QgsReadWriteConte
       QDomElement elemPointLight = elemPointLights.firstChildElement( QStringLiteral( "point-light" ) );
       while ( !elemPointLight.isNull() )
       {
-        std::unique_ptr< QgsPointLightSettings > pointLight = std::make_unique< QgsPointLightSettings >();
+        auto pointLight = std::make_unique<QgsPointLightSettings>();
         pointLight->readXml( elemPointLight, context );
         mLightSources << pointLight.release();
         elemPointLight = elemPointLight.nextSiblingElement( QStringLiteral( "point-light" ) );
@@ -215,7 +209,7 @@ void Qgs3DMapSettings::readXml( const QDomElement &elem, const QgsReadWriteConte
     else
     {
       // QGIS <= 3.4 did not have light configuration
-      std::unique_ptr< QgsPointLightSettings > defaultLight = std::make_unique< QgsPointLightSettings >();
+      auto defaultLight = std::make_unique<QgsPointLightSettings>();
       defaultLight->setPosition( QgsVector3D( 0, 1000, 0 ) );
       mLightSources << defaultLight.release();
     }
@@ -226,7 +220,7 @@ void Qgs3DMapSettings::readXml( const QDomElement &elem, const QgsReadWriteConte
       QDomElement elemDirectionalLight = elemDirectionalLights.firstChildElement( QStringLiteral( "directional-light" ) );
       while ( !elemDirectionalLight.isNull() )
       {
-        std::unique_ptr< QgsDirectionalLightSettings > directionalLight = std::make_unique< QgsDirectionalLightSettings >();
+        auto directionalLight = std::make_unique<QgsDirectionalLightSettings>();
         directionalLight->readXml( elemDirectionalLight, context );
         mLightSources << directionalLight.release();
         elemDirectionalLight = elemDirectionalLight.nextSiblingElement( QStringLiteral( "directional-light" ) );
@@ -242,40 +236,16 @@ void Qgs3DMapSettings::readXml( const QDomElement &elem, const QgsReadWriteConte
     mapLayers << QgsMapLayerRef( elemMapLayer.attribute( QStringLiteral( "id" ) ) );
     elemMapLayer = elemMapLayer.nextSiblingElement( QStringLiteral( "layer" ) );
   }
-  mLayers = mapLayers;  // needs to resolve refs afterwards
+  mLayers = mapLayers; // needs to resolve refs afterwards
 
   QDomElement elemTerrainGenerator = elemTerrain.firstChildElement( QStringLiteral( "generator" ) );
-  QString terrainGenType = elemTerrainGenerator.attribute( QStringLiteral( "type" ) );
-  if ( terrainGenType == QLatin1String( "dem" ) )
+  const QString terrainGenType = elemTerrainGenerator.attribute( QStringLiteral( "type" ) );
+  std::unique_ptr<QgsAbstractTerrainSettings> terrainSettings( Qgs3D::terrainRegistry()->createTerrainSettings( terrainGenType ) );
+  if ( terrainSettings )
   {
-    QgsDemTerrainGenerator *demTerrainGenerator = new QgsDemTerrainGenerator;
-    demTerrainGenerator->setCrs( mCrs, mTransformContext );
-    setTerrainGenerator( demTerrainGenerator );
+    terrainSettings->readXml( elemTerrain, context );
+    setTerrainSettings( terrainSettings.release() );
   }
-  else if ( terrainGenType == QLatin1String( "online" ) )
-  {
-    QgsOnlineTerrainGenerator *onlineTerrainGenerator = new QgsOnlineTerrainGenerator;
-    onlineTerrainGenerator->setCrs( mCrs, mTransformContext );
-    setTerrainGenerator( onlineTerrainGenerator );
-  }
-  else if ( terrainGenType == QLatin1String( "mesh" ) )
-  {
-    QgsMeshTerrainGenerator *meshTerrainGenerator = new QgsMeshTerrainGenerator;
-    meshTerrainGenerator->setCrs( mCrs, mTransformContext );
-    setTerrainGenerator( meshTerrainGenerator );
-  }
-  else if ( terrainGenType == QLatin1String( "quantizedmesh" ) )
-  {
-    QgsQuantizedMeshTerrainGenerator *qmTerrainGenerator = new QgsQuantizedMeshTerrainGenerator;
-    setTerrainGenerator( qmTerrainGenerator );
-  }
-  else // "flat"
-  {
-    QgsFlatTerrainGenerator *flatGen = new QgsFlatTerrainGenerator;
-    flatGen->setCrs( mCrs );
-    setTerrainGenerator( flatGen );
-  }
-  mTerrainGenerator->readXml( elemTerrainGenerator );
 
   QDomElement elemSkybox = elem.firstChildElement( QStringLiteral( "skybox" ) );
   mIsSkyboxEnabled = elemSkybox.attribute( QStringLiteral( "skybox-enabled" ) ).toInt();
@@ -312,6 +282,8 @@ void Qgs3DMapSettings::readXml( const QDomElement &elem, const QgsReadWriteConte
   mShowCameraRotationCenter = elemDebug.attribute( QStringLiteral( "camera-rotation-center" ), QStringLiteral( "0" ) ).toInt();
   mShowLightSources = elemDebug.attribute( QStringLiteral( "show-light-sources" ), QStringLiteral( "0" ) ).toInt();
   mIsFpsCounterEnabled = elemDebug.attribute( QStringLiteral( "show-fps-counter" ), QStringLiteral( "0" ) ).toInt();
+  mStopUpdates = elemDebug.attribute( QStringLiteral( "stop-updates" ), QStringLiteral( "0" ) ).toInt();
+  mShowDebugPanel = elemDebug.attribute( QStringLiteral( "debug-panel" ), QStringLiteral( "0" ) ).toInt();
 
   QDomElement elemTemporalRange = elem.firstChildElement( QStringLiteral( "temporal-range" ) );
   QDateTime start = QDateTime::fromString( elemTemporalRange.attribute( QStringLiteral( "start" ) ), Qt::ISODate );
@@ -320,7 +292,6 @@ void Qgs3DMapSettings::readXml( const QDomElement &elem, const QgsReadWriteConte
 
   QDomElement elem3dAxis = elem.firstChildElement( QStringLiteral( "axis3d" ) );
   m3dAxisSettings.readXml( elem3dAxis, context );
-
 }
 
 QDomElement Qgs3DMapSettings::writeXml( QDomDocument &doc, const QgsReadWriteContext &context ) const
@@ -345,7 +316,7 @@ QDomElement Qgs3DMapSettings::writeXml( QDomDocument &doc, const QgsReadWriteCon
 
   QDomElement elemCamera = doc.createElement( QStringLiteral( "camera" ) );
   elemCamera.setAttribute( QStringLiteral( "field-of-view" ), mFieldOfView );
-  elemCamera.setAttribute( QStringLiteral( "projection-type" ), static_cast< int >( mProjectionType ) );
+  elemCamera.setAttribute( QStringLiteral( "projection-type" ), static_cast<int>( mProjectionType ) );
   switch ( mCameraNavigationMode )
   {
     case Qgis::NavigationMode::TerrainBased:
@@ -369,12 +340,7 @@ QDomElement Qgs3DMapSettings::writeXml( QDomDocument &doc, const QgsReadWriteCon
 
   QDomElement elemTerrain = doc.createElement( QStringLiteral( "terrain" ) );
   elemTerrain.setAttribute( QStringLiteral( "terrain-rendering-enabled" ), mTerrainRenderingEnabled ? 1 : 0 );
-  elemTerrain.setAttribute( QStringLiteral( "exaggeration" ), QString::number( mTerrainVerticalScale ) );
-  elemTerrain.setAttribute( QStringLiteral( "texture-size" ), mMapTileResolution );
-  elemTerrain.setAttribute( QStringLiteral( "max-terrain-error" ), QString::number( mMaxTerrainScreenError ) );
-  elemTerrain.setAttribute( QStringLiteral( "max-ground-error" ), QString::number( mMaxTerrainGroundError ) );
   elemTerrain.setAttribute( QStringLiteral( "shading-enabled" ), mTerrainShadingEnabled ? 1 : 0 );
-  elemTerrain.setAttribute( QStringLiteral( "elevation-offset" ), mTerrainElevationOffset );
 
   QDomElement elemTerrainShadingMaterial = doc.createElement( QStringLiteral( "shading-material" ) );
   mTerrainShadingMaterial.writeXml( elemTerrainShadingMaterial, context );
@@ -402,8 +368,8 @@ QDomElement Qgs3DMapSettings::writeXml( QDomDocument &doc, const QgsReadWriteCon
   elemTerrain.appendChild( elemMapLayers );
 
   QDomElement elemTerrainGenerator = doc.createElement( QStringLiteral( "generator" ) );
-  elemTerrainGenerator.setAttribute( QStringLiteral( "type" ), QgsTerrainGenerator::typeToString( mTerrainGenerator->type() ) );
-  mTerrainGenerator->writeXml( elemTerrainGenerator );
+  elemTerrainGenerator.setAttribute( QStringLiteral( "type" ), mTerrainSettings->type() );
+  mTerrainSettings->writeXml( elemTerrain, context );
   elemTerrain.appendChild( elemTerrainGenerator );
   elem.appendChild( elemTerrain );
 
@@ -427,6 +393,8 @@ QDomElement Qgs3DMapSettings::writeXml( QDomDocument &doc, const QgsReadWriteCon
   elemDebug.setAttribute( QStringLiteral( "camera-rotation-center" ), mShowCameraRotationCenter ? 1 : 0 );
   elemDebug.setAttribute( QStringLiteral( "show-light-sources" ), mShowLightSources ? 1 : 0 );
   elemDebug.setAttribute( QStringLiteral( "show-fps-counter" ), mIsFpsCounterEnabled ? 1 : 0 );
+  elemDebug.setAttribute( QStringLiteral( "stop-updates" ), mStopUpdates ? 1 : 0 );
+  elemDebug.setAttribute( QStringLiteral( "debug-panel" ), mShowDebugPanel ? 1 : 0 );
   elem.appendChild( elemDebug );
 
   QDomElement elemEyeDomeLighting = doc.createElement( QStringLiteral( "eye-dome-lighting" ) );
@@ -436,7 +404,7 @@ QDomElement Qgs3DMapSettings::writeXml( QDomDocument &doc, const QgsReadWriteCon
   elem.appendChild( elemEyeDomeLighting );
 
   QDomElement elemNavigationSync = doc.createElement( QStringLiteral( "navigation-sync" ) );
-  elemNavigationSync.setAttribute( QStringLiteral( "view-sync-mode" ), ( int )mViewSyncMode );
+  elemNavigationSync.setAttribute( QStringLiteral( "view-sync-mode" ), ( int ) mViewSyncMode );
   elemNavigationSync.setAttribute( QStringLiteral( "view-frustum-visualization-enabled" ), mVisualizeViewFrustum ? 1 : 0 );
   elem.appendChild( elemNavigationSync );
 
@@ -470,11 +438,17 @@ void Qgs3DMapSettings::resolveReferences( const QgsProject &project )
     layerRef.setLayer( project.mapLayer( layerRef.layerId ) );
   }
 
-  mTerrainGenerator->resolveReferences( project );
+  if ( mTerrainSettings )
+  {
+    mTerrainSettings->resolveReferences( &project );
 
-  // Set extent now that layer-based generators actually have a chance to know their CRS
-  QgsRectangle terrainExtent = Qgs3DUtils::tryReprojectExtent2D( mExtent, mCrs, mTerrainGenerator->crs(), mTransformContext );
-  mTerrainGenerator->setExtent( terrainExtent );
+    std::unique_ptr<QgsTerrainGenerator> terrainGenerator = mTerrainSettings->createTerrainGenerator( Qgs3DRenderContext::fromMapSettings( this ) );
+    if ( terrainGenerator )
+    {
+      setTerrainGenerator( terrainGenerator.release() );
+    }
+    emit terrainSettingsChanged();
+  }
 }
 
 QgsRectangle Qgs3DMapSettings::extent() const
@@ -506,7 +480,11 @@ void Qgs3DMapSettings::setOrigin( const QgsVector3D &origin )
 {
   QGIS_PROTECT_QOBJECT_THREAD_ACCESS
 
+  if ( origin == mOrigin )
+    return;
+
   mOrigin = origin;
+  emit originChanged();
 }
 
 QgsVector3D Qgs3DMapSettings::origin() const
@@ -626,18 +604,21 @@ void Qgs3DMapSettings::setTerrainVerticalScale( double zScale )
 {
   QGIS_PROTECT_QOBJECT_THREAD_ACCESS
 
-  if ( zScale == mTerrainVerticalScale )
+  if ( zScale == mTerrainSettings->verticalScale() )
     return;
 
-  mTerrainVerticalScale = zScale;
+  mTerrainSettings->setVerticalScale( zScale );
+  Q_NOWARN_DEPRECATED_PUSH
   emit terrainVerticalScaleChanged();
+  Q_NOWARN_DEPRECATED_POP
+  emit terrainSettingsChanged();
 }
 
 double Qgs3DMapSettings::terrainVerticalScale() const
 {
   QGIS_PROTECT_QOBJECT_THREAD_ACCESS
 
-  return mTerrainVerticalScale;
+  return mTerrainSettings->verticalScale();
 }
 
 void Qgs3DMapSettings::setLayers( const QList<QgsMapLayer *> &layers )
@@ -672,46 +653,56 @@ void Qgs3DMapSettings::configureTerrainFromProject( QgsProjectElevationPropertie
   QGIS_PROTECT_QOBJECT_THREAD_ACCESS
 
   setExtent( fullExtent );
-  if ( properties->terrainProvider()->type() == QLatin1String( "flat" ) )
-  {
-    QgsFlatTerrainGenerator *flatTerrain = new QgsFlatTerrainGenerator;
-    flatTerrain->setCrs( crs() );
-    setTerrainGenerator( flatTerrain );
 
-    setTerrainElevationOffset( properties->terrainProvider()->offset() );
+  std::unique_ptr<QgsAbstractTerrainSettings> terrainSettings( Qgs3D::terrainRegistry()->configureTerrainFromProject( properties ) );
+  if ( terrainSettings )
+  {
+    setTerrainSettings( terrainSettings.release() );
   }
-  else if ( properties->terrainProvider()->type() == QLatin1String( "raster" ) )
+}
+
+const QgsAbstractTerrainSettings *Qgs3DMapSettings::terrainSettings() const
+{
+  QGIS_PROTECT_QOBJECT_THREAD_ACCESS
+
+  return mTerrainSettings.get();
+}
+
+void Qgs3DMapSettings::setTerrainSettings( QgsAbstractTerrainSettings *settings )
+{
+  QGIS_PROTECT_QOBJECT_THREAD_ACCESS
+
+  bool hasChanged = false;
+  if ( settings == mTerrainSettings.get() )
   {
-    QgsRasterDemTerrainProvider *rasterProvider = qgis::down_cast< QgsRasterDemTerrainProvider * >( properties->terrainProvider() );
-
-    QgsDemTerrainGenerator *demTerrainGen = new QgsDemTerrainGenerator;
-    demTerrainGen->setCrs( crs(), QgsProject::instance()->transformContext() );
-    demTerrainGen->setLayer( rasterProvider->layer() );
-    setTerrainGenerator( demTerrainGen );
-
-    setTerrainElevationOffset( properties->terrainProvider()->offset() );
-    setTerrainVerticalScale( properties->terrainProvider()->scale() );
-  }
-  else if ( properties->terrainProvider()->type() == QLatin1String( "mesh" ) )
-  {
-    QgsMeshTerrainProvider *meshProvider = qgis::down_cast< QgsMeshTerrainProvider * >( properties->terrainProvider() );
-
-    QgsMeshTerrainGenerator *newTerrainGenerator = new QgsMeshTerrainGenerator;
-    newTerrainGenerator->setCrs( crs(), QgsProject::instance()->transformContext() );
-    newTerrainGenerator->setLayer( meshProvider->layer() );
-    std::unique_ptr< QgsMesh3DSymbol > symbol( newTerrainGenerator->symbol()->clone() );
-    symbol->setVerticalScale( properties->terrainProvider()->scale() );
-    newTerrainGenerator->setSymbol( symbol.release() );
-    setTerrainGenerator( newTerrainGenerator );
-
-    setTerrainElevationOffset( properties->terrainProvider()->offset() );
-    setTerrainVerticalScale( properties->terrainProvider()->scale() );
+    // emit signals anyway. We don't know if the caller changed settings on the pointer before calling this..
+    hasChanged = true;
   }
   else
   {
-    QgsFlatTerrainGenerator *flatTerrain = new QgsFlatTerrainGenerator;
-    flatTerrain->setCrs( crs() );
-    setTerrainGenerator( flatTerrain );
+    // ensure to generate the terrain if the settings have changed or if the terrain has never been generated.
+    hasChanged = !settings->equals( mTerrainSettings.get() ) || !mTerrainGenerator;
+    mTerrainSettings.reset( settings );
+  }
+
+  if ( hasChanged )
+  {
+    std::unique_ptr<QgsTerrainGenerator> terrainGenerator = mTerrainSettings->createTerrainGenerator( Qgs3DRenderContext::fromMapSettings( this ) );
+    if ( terrainGenerator )
+    {
+      setTerrainGenerator( terrainGenerator.release() );
+    }
+
+    // emit all the signals, we don't know exactly what's changed
+    Q_NOWARN_DEPRECATED_PUSH
+    emit mapTileResolutionChanged();
+    emit maxTerrainScreenErrorChanged();
+    emit maxTerrainGroundErrorChanged();
+    emit terrainElevationOffsetChanged( mTerrainSettings->elevationOffset() );
+    emit terrainVerticalScaleChanged();
+    Q_NOWARN_DEPRECATED_POP
+
+    emit terrainSettingsChanged();
   }
 }
 
@@ -719,71 +710,84 @@ void Qgs3DMapSettings::setMapTileResolution( int res )
 {
   QGIS_PROTECT_QOBJECT_THREAD_ACCESS
 
-  if ( mMapTileResolution == res )
+  if ( mTerrainSettings->mapTileResolution() == res )
     return;
 
-  mMapTileResolution = res;
+  mTerrainSettings->setMapTileResolution( res );
+  Q_NOWARN_DEPRECATED_PUSH
   emit mapTileResolutionChanged();
+  Q_NOWARN_DEPRECATED_POP
+  emit terrainSettingsChanged();
 }
 
 int Qgs3DMapSettings::mapTileResolution() const
 {
   QGIS_PROTECT_QOBJECT_THREAD_ACCESS
 
-  return mMapTileResolution;
+  return mTerrainSettings->mapTileResolution();
 }
 
-void Qgs3DMapSettings::setMaxTerrainScreenError( float error )
+void Qgs3DMapSettings::setMaxTerrainScreenError( double error )
 {
   QGIS_PROTECT_QOBJECT_THREAD_ACCESS
 
-  if ( mMaxTerrainScreenError == error )
+  if ( mTerrainSettings->maximumScreenError() == error )
     return;
 
-  mMaxTerrainScreenError = error;
+  mTerrainSettings->setMaximumScreenError( error );
+  Q_NOWARN_DEPRECATED_PUSH
   emit maxTerrainScreenErrorChanged();
+  Q_NOWARN_DEPRECATED_POP
+  emit terrainSettingsChanged();
 }
 
-float Qgs3DMapSettings::maxTerrainScreenError() const
+double Qgs3DMapSettings::maxTerrainScreenError() const
 {
   QGIS_PROTECT_QOBJECT_THREAD_ACCESS
 
-  return mMaxTerrainScreenError;
+  return mTerrainSettings->maximumScreenError();
 }
 
-void Qgs3DMapSettings::setMaxTerrainGroundError( float error )
+void Qgs3DMapSettings::setMaxTerrainGroundError( double error )
 {
   QGIS_PROTECT_QOBJECT_THREAD_ACCESS
 
-  if ( mMaxTerrainGroundError == error )
+  if ( mTerrainSettings->maximumGroundError() == error )
     return;
 
-  mMaxTerrainGroundError = error;
+  mTerrainSettings->setMaximumGroundError( error );
+  Q_NOWARN_DEPRECATED_PUSH
   emit maxTerrainGroundErrorChanged();
+  Q_NOWARN_DEPRECATED_POP
+
+  emit terrainSettingsChanged();
 }
 
-void Qgs3DMapSettings::setTerrainElevationOffset( float offset )
+void Qgs3DMapSettings::setTerrainElevationOffset( double offset )
 {
   QGIS_PROTECT_QOBJECT_THREAD_ACCESS
 
-  if ( mTerrainElevationOffset == offset )
+  if ( mTerrainSettings->elevationOffset() == offset )
     return;
-  mTerrainElevationOffset = offset;
-  emit terrainElevationOffsetChanged( mTerrainElevationOffset );
+  mTerrainSettings->setElevationOffset( offset );
+  Q_NOWARN_DEPRECATED_PUSH
+  emit terrainElevationOffsetChanged( offset );
+  Q_NOWARN_DEPRECATED_POP
+  emit terrainSettingsChanged();
 }
 
-float Qgs3DMapSettings::terrainElevationOffset() const
+double Qgs3DMapSettings::terrainElevationOffset() const
 {
   QGIS_PROTECT_QOBJECT_THREAD_ACCESS
 
-  return mTerrainElevationOffset;
+  return mTerrainSettings->elevationOffset();
 }
 
-float Qgs3DMapSettings::maxTerrainGroundError() const
+double Qgs3DMapSettings::maxTerrainGroundError() const
 {
   QGIS_PROTECT_QOBJECT_THREAD_ACCESS
 
-  return mMaxTerrainGroundError;
+  return mTerrainSettings->maximumGroundError();
 }
 
 void Qgs3DMapSettings::setTerrainGenerator( QgsTerrainGenerator *gen )
@@ -976,6 +980,24 @@ bool Qgs3DMapSettings::showLabels() const
   return mShowLabels;
 }
 
+void Qgs3DMapSettings::setStopUpdates( bool enabled )
+{
+  QGIS_PROTECT_QOBJECT_THREAD_ACCESS
+
+  if ( mStopUpdates == enabled )
+    return;
+
+  mStopUpdates = enabled;
+  emit stopUpdatesChanged();
+}
+
+bool Qgs3DMapSettings::stopUpdates() const
+{
+  QGIS_PROTECT_QOBJECT_THREAD_ACCESS
+
+  return mStopUpdates;
+}
+
 void Qgs3DMapSettings::setEyeDomeLightingEnabled( bool enabled )
 {
   QGIS_PROTECT_QOBJECT_THREAD_ACCESS
@@ -1049,11 +1071,11 @@ void Qgs3DMapSettings::setLightSources( const QList<QgsLightSource *> &lights )
         switch ( mLightSources[i]->type() )
         {
           case Qgis::LightSourceType::Point:
-            if ( *static_cast< QgsPointLightSettings * >( mLightSources[i] ) == *static_cast< QgsPointLightSettings * >( lights[i] ) )
+            if ( *static_cast<QgsPointLightSettings *>( mLightSources[i] ) == *static_cast<QgsPointLightSettings *>( lights[i] ) )
               continue;
             break;
           case Qgis::LightSourceType::Directional:
-            if ( *static_cast< QgsDirectionalLightSettings * >( mLightSources[i] ) == *static_cast< QgsDirectionalLightSettings * >( lights[i] ) )
+            if ( *static_cast<QgsDirectionalLightSettings *>( mLightSources[i] ) == *static_cast<QgsDirectionalLightSettings *>( lights[i] ) )
               continue;
             break;
         }
@@ -1228,6 +1250,24 @@ bool Qgs3DMapSettings::isFpsCounterEnabled() const
   return mIsFpsCounterEnabled;
 }
 
+void Qgs3DMapSettings::setShowDebugPanel( const bool enabled )
+{
+  QGIS_PROTECT_QOBJECT_THREAD_ACCESS
+
+  if ( mShowDebugPanel == enabled )
+    return;
+
+  mShowDebugPanel = enabled;
+  emit showDebugPanelChanged( enabled );
+}
+
+bool Qgs3DMapSettings::showDebugPanel() const
+{
+  QGIS_PROTECT_QOBJECT_THREAD_ACCESS
+
+  return mShowDebugPanel;
+}
+
 void Qgs3DMapSettings::setDebugShadowMapSettings( bool enabled, Qt::Corner corner, double size )
 {
   QGIS_PROTECT_QOBJECT_THREAD_ACCESS
@@ -1395,11 +1435,7 @@ void Qgs3DMapSettings::connectChangedSignalsToSettingsChanged()
   connect( this, &Qgs3DMapSettings::selectionColorChanged, this, &Qgs3DMapSettings::settingsChanged );
   connect( this, &Qgs3DMapSettings::layersChanged, this, &Qgs3DMapSettings::settingsChanged );
   connect( this, &Qgs3DMapSettings::terrainGeneratorChanged, this, &Qgs3DMapSettings::settingsChanged );
-  connect( this, &Qgs3DMapSettings::terrainVerticalScaleChanged, this, &Qgs3DMapSettings::settingsChanged );
-  connect( this, &Qgs3DMapSettings::mapTileResolutionChanged, this, &Qgs3DMapSettings::settingsChanged );
-  connect( this, &Qgs3DMapSettings::maxTerrainScreenErrorChanged, this, &Qgs3DMapSettings::settingsChanged );
-  connect( this, &Qgs3DMapSettings::maxTerrainGroundErrorChanged, this, &Qgs3DMapSettings::settingsChanged );
-  connect( this, &Qgs3DMapSettings::terrainElevationOffsetChanged, this, &Qgs3DMapSettings::settingsChanged );
+  connect( this, &Qgs3DMapSettings::terrainSettingsChanged, this, &Qgs3DMapSettings::settingsChanged );
   connect( this, &Qgs3DMapSettings::terrainShadingChanged, this, &Qgs3DMapSettings::settingsChanged );
   connect( this, &Qgs3DMapSettings::terrainMapThemeChanged, this, &Qgs3DMapSettings::settingsChanged );
   connect( this, &Qgs3DMapSettings::renderersChanged, this, &Qgs3DMapSettings::settingsChanged );
@@ -1425,6 +1461,8 @@ void Qgs3DMapSettings::connectChangedSignalsToSettingsChanged()
   connect( this, &Qgs3DMapSettings::ambientOcclusionSettingsChanged, this, &Qgs3DMapSettings::settingsChanged );
   connect( this, &Qgs3DMapSettings::extentChanged, this, &Qgs3DMapSettings::settingsChanged );
   connect( this, &Qgs3DMapSettings::showExtentIn2DViewChanged, this, &Qgs3DMapSettings::settingsChanged );
+  connect( this, &Qgs3DMapSettings::stopUpdatesChanged, this, &Qgs3DMapSettings::settingsChanged );
+  connect( this, &Qgs3DMapSettings::showDebugPanelChanged, this, &Qgs3DMapSettings::settingsChanged );
 }
 
 
