@@ -24,9 +24,7 @@
 
 void QgsLocationBasedAlgorithm::addPredicateParameter()
 {
-  std::unique_ptr< QgsProcessingParameterEnum > predicateParam( new QgsProcessingParameterEnum( QStringLiteral( "PREDICATE" ),
-      QObject::tr( "Where the features (geometric predicate)" ),
-      predicateOptionsList(), true, QVariant::fromValue( QList< int >() << 0 ) ) );
+  auto predicateParam = std::make_unique<QgsProcessingParameterEnum>( QStringLiteral( "PREDICATE" ), QObject::tr( "Where the features (geometric predicate)" ), predicateOptionsList(), true, QVariant::fromValue( QList<int>() << 0 ) );
 
   QVariantMap predicateMetadata;
   QVariantMap widgetMetadata;
@@ -66,39 +64,29 @@ QgsLocationBasedAlgorithm::Predicate QgsLocationBasedAlgorithm::reversePredicate
 QStringList QgsLocationBasedAlgorithm::predicateOptionsList() const
 {
   return QStringList() << QObject::tr( "intersect" )
-         << QObject::tr( "contain" )
-         << QObject::tr( "disjoint" )
-         << QObject::tr( "equal" )
-         << QObject::tr( "touch" )
-         << QObject::tr( "overlap" )
-         << QObject::tr( "are within" )
-         << QObject::tr( "cross" );
+                       << QObject::tr( "contain" )
+                       << QObject::tr( "disjoint" )
+                       << QObject::tr( "equal" )
+                       << QObject::tr( "touch" )
+                       << QObject::tr( "overlap" )
+                       << QObject::tr( "are within" )
+                       << QObject::tr( "cross" );
 }
 
-void QgsLocationBasedAlgorithm::process( const QgsProcessingContext &context, QgsFeatureSource *targetSource,
-    QgsFeatureSource *intersectSource,
-    const QList< int > &selectedPredicates,
-    const std::function < void( const QgsFeature & ) > &handleFeatureFunction,
-    bool onlyRequireTargetIds,
-    QgsProcessingFeedback *feedback,
-    const QgsFeatureIds &skipTargetFeatureIds )
+void QgsLocationBasedAlgorithm::process( const QgsProcessingContext &context, QgsFeatureSource *targetSource, QgsFeatureSource *intersectSource, const QList<int> &selectedPredicates, const std::function<void( const QgsFeature & )> &handleFeatureFunction, bool onlyRequireTargetIds, QgsProcessingFeedback *feedback, const QgsFeatureIds &skipTargetFeatureIds )
 {
   // skip if there are no features to select from!
   if ( mTargetFeatureCount == 0 )
     return;
 
   // skip if intersect layer is empty, unless we are looking for disjoints
-  if ( mIntersectFeatureCount == 0 &&
-       !selectedPredicates.contains( Disjoint ) )
+  if ( mIntersectFeatureCount == 0 && !selectedPredicates.contains( Disjoint ) )
     return;
 
-  if ( mTargetFeatureCount > 0 && mIntersectFeatureCount > 0 &&
-       mTargetFeatureCount < mIntersectFeatureCount )
+  if ( mTargetFeatureCount > 0 && mIntersectFeatureCount > 0 && mTargetFeatureCount < mIntersectFeatureCount )
   {
     // joining FEWER features to a layer with MORE features. So we iterate over the FEW features and find matches from the MANY
-    processByIteratingOverTargetSource( context, targetSource, intersectSource,
-                                        selectedPredicates, handleFeatureFunction,
-                                        onlyRequireTargetIds, feedback, skipTargetFeatureIds );
+    processByIteratingOverTargetSource( context, targetSource, intersectSource, selectedPredicates, handleFeatureFunction, onlyRequireTargetIds, feedback, skipTargetFeatureIds );
   }
   else
   {
@@ -108,19 +96,11 @@ void QgsLocationBasedAlgorithm::process( const QgsProcessingContext &context, Qg
 
     // TODO - consider using more heuristics to determine whether it's always best to iterate over the intersect
     // source.
-    processByIteratingOverIntersectSource( context, targetSource, intersectSource,
-                                           selectedPredicates, handleFeatureFunction,
-                                           onlyRequireTargetIds, feedback, skipTargetFeatureIds );
+    processByIteratingOverIntersectSource( context, targetSource, intersectSource, selectedPredicates, handleFeatureFunction, onlyRequireTargetIds, feedback, skipTargetFeatureIds );
   }
 }
 
-void QgsLocationBasedAlgorithm::processByIteratingOverTargetSource( const QgsProcessingContext &context, QgsFeatureSource *targetSource,
-    QgsFeatureSource *intersectSource,
-    const QList< int > &selectedPredicates,
-    const std::function < void( const QgsFeature & ) > &handleFeatureFunction,
-    bool onlyRequireTargetIds,
-    QgsProcessingFeedback *feedback,
-    const QgsFeatureIds &skipTargetFeatureIds )
+void QgsLocationBasedAlgorithm::processByIteratingOverTargetSource( const QgsProcessingContext &context, QgsFeatureSource *targetSource, QgsFeatureSource *intersectSource, const QList<int> &selectedPredicates, const std::function<void( const QgsFeature & )> &handleFeatureFunction, bool onlyRequireTargetIds, QgsProcessingFeedback *feedback, const QgsFeatureIds &skipTargetFeatureIds )
 {
   if ( intersectSource->hasSpatialIndex() == Qgis::SpatialIndexPresence::NotPresent )
     feedback->pushWarning( QObject::tr( "No spatial index exists for intersect layer, performance will be severely degraded" ) );
@@ -131,10 +111,10 @@ void QgsLocationBasedAlgorithm::processByIteratingOverTargetSource( const QgsPro
     request.setNoAttributes();
 
   QgsFeatureIterator fIt = targetSource->getFeatures( request );
-  double step = mTargetFeatureCount > 0 ? 100.0 / static_cast< double >( mTargetFeatureCount ) : 1;
+  double step = mTargetFeatureCount > 0 ? 100.0 / static_cast<double>( mTargetFeatureCount ) : 1;
   int current = 0;
   QgsFeature f;
-  std::unique_ptr< QgsGeometryEngine > engine;
+  std::unique_ptr<QgsGeometryEngine> engine;
   while ( fIt.nextFeature( f ) )
   {
     if ( feedback->isCanceled() )
@@ -168,7 +148,7 @@ void QgsLocationBasedAlgorithm::processByIteratingOverTargetSource( const QgsPro
 
       for ( int predicate : selectedPredicates )
       {
-        switch ( static_cast< Predicate>( predicate ) )
+        switch ( static_cast<Predicate>( predicate ) )
         {
           case Intersects:
             isMatch = engine->intersects( testFeature.geometry().constGet() );
@@ -221,13 +201,7 @@ void QgsLocationBasedAlgorithm::processByIteratingOverTargetSource( const QgsPro
   }
 }
 
-void QgsLocationBasedAlgorithm::processByIteratingOverIntersectSource( const QgsProcessingContext &context, QgsFeatureSource *targetSource,
-    QgsFeatureSource *intersectSource,
-    const QList< int > &selectedPredicates,
-    const std::function < void( const QgsFeature & ) > &handleFeatureFunction,
-    bool onlyRequireTargetIds,
-    QgsProcessingFeedback *feedback,
-    const QgsFeatureIds &skipTargetFeatureIds )
+void QgsLocationBasedAlgorithm::processByIteratingOverIntersectSource( const QgsProcessingContext &context, QgsFeatureSource *targetSource, QgsFeatureSource *intersectSource, const QList<int> &selectedPredicates, const std::function<void( const QgsFeature & )> &handleFeatureFunction, bool onlyRequireTargetIds, QgsProcessingFeedback *feedback, const QgsFeatureIds &skipTargetFeatureIds )
 {
   if ( targetSource->hasSpatialIndex() == Qgis::SpatialIndexPresence::NotPresent )
     feedback->pushWarning( QObject::tr( "No spatial index exists for input layer, performance will be severely degraded" ) );
@@ -235,11 +209,11 @@ void QgsLocationBasedAlgorithm::processByIteratingOverIntersectSource( const Qgs
   // build a list of 'reversed' predicates, because in this function
   // we actually test the reverse of what the user wants (allowing us
   // to prepare geometries and optimise the algorithm)
-  QList< Predicate > predicates;
+  QList<Predicate> predicates;
   predicates.reserve( selectedPredicates.count() );
   for ( int i : selectedPredicates )
   {
-    predicates << reversePredicate( static_cast< Predicate >( i ) );
+    predicates << reversePredicate( static_cast<Predicate>( i ) );
   }
 
   QgsFeatureIds disjointSet;
@@ -249,10 +223,10 @@ void QgsLocationBasedAlgorithm::processByIteratingOverIntersectSource( const Qgs
   QgsFeatureIds foundSet;
   QgsFeatureRequest request = QgsFeatureRequest().setNoAttributes().setDestinationCrs( mTargetCrs, context.transformContext() );
   QgsFeatureIterator fIt = intersectSource->getFeatures( request );
-  double step = mIntersectFeatureCount > 0 ? 100.0 / static_cast< double >( mIntersectFeatureCount ) : 1;
+  double step = mIntersectFeatureCount > 0 ? 100.0 / static_cast<double>( mIntersectFeatureCount ) : 1;
   int current = 0;
   QgsFeature f;
-  std::unique_ptr< QgsGeometryEngine > engine;
+  std::unique_ptr<QgsGeometryEngine> engine;
   while ( fIt.nextFeature( f ) )
   {
     if ( feedback->isCanceled() )
@@ -340,7 +314,6 @@ void QgsLocationBasedAlgorithm::processByIteratingOverIntersectSource( const Qgs
         foundSet.insert( testFeature.id() );
         handleFeatureFunction( testFeature );
       }
-
     }
 
     current += 1;
@@ -370,20 +343,15 @@ void QgsLocationBasedAlgorithm::processByIteratingOverIntersectSource( const Qgs
 void QgsSelectByLocationAlgorithm::initAlgorithm( const QVariantMap & )
 {
   QStringList methods = QStringList() << QObject::tr( "creating new selection" )
-                        << QObject::tr( "adding to current selection" )
-                        << QObject::tr( "selecting within current selection" )
-                        << QObject::tr( "removing from current selection" );
+                                      << QObject::tr( "adding to current selection" )
+                                      << QObject::tr( "selecting within current selection" )
+                                      << QObject::tr( "removing from current selection" );
 
-  addParameter( new QgsProcessingParameterVectorLayer( QStringLiteral( "INPUT" ), QObject::tr( "Select features from" ),
-                QList< int >() << static_cast< int >( Qgis::ProcessingSourceType::VectorAnyGeometry ) ) );
+  addParameter( new QgsProcessingParameterVectorLayer( QStringLiteral( "INPUT" ), QObject::tr( "Select features from" ), QList<int>() << static_cast<int>( Qgis::ProcessingSourceType::VectorAnyGeometry ) ) );
   addPredicateParameter();
-  addParameter( new QgsProcessingParameterFeatureSource( QStringLiteral( "INTERSECT" ),
-                QObject::tr( "By comparing to the features from" ),
-                QList< int >() << static_cast< int >( Qgis::ProcessingSourceType::VectorAnyGeometry ) ) );
+  addParameter( new QgsProcessingParameterFeatureSource( QStringLiteral( "INTERSECT" ), QObject::tr( "By comparing to the features from" ), QList<int>() << static_cast<int>( Qgis::ProcessingSourceType::VectorAnyGeometry ) ) );
 
-  addParameter( new QgsProcessingParameterEnum( QStringLiteral( "METHOD" ),
-                QObject::tr( "Modify current selection by" ),
-                methods, false, 0 ) );
+  addParameter( new QgsProcessingParameterEnum( QStringLiteral( "METHOD" ), QObject::tr( "Modify current selection by" ), methods, false, 0 ) );
 }
 
 QString QgsSelectByLocationAlgorithm::name() const
@@ -433,16 +401,15 @@ QVariantMap QgsSelectByLocationAlgorithm::processAlgorithm( const QVariantMap &p
   if ( !selectLayer )
     throw QgsProcessingException( QObject::tr( "Could not load source layer for INPUT" ) );
 
-  Qgis::SelectBehavior method = static_cast< Qgis::SelectBehavior >( parameterAsEnum( parameters, QStringLiteral( "METHOD" ), context ) );
-  std::unique_ptr< QgsFeatureSource > intersectSource( parameterAsSource( parameters, QStringLiteral( "INTERSECT" ), context ) );
+  Qgis::SelectBehavior method = static_cast<Qgis::SelectBehavior>( parameterAsEnum( parameters, QStringLiteral( "METHOD" ), context ) );
+  std::unique_ptr<QgsFeatureSource> intersectSource( parameterAsSource( parameters, QStringLiteral( "INTERSECT" ), context ) );
   if ( !intersectSource )
     throw QgsProcessingException( invalidSourceError( parameters, QStringLiteral( "INTERSECT" ) ) );
 
-  const QList< int > selectedPredicates = parameterAsEnums( parameters, QStringLiteral( "PREDICATE" ), context );
+  const QList<int> selectedPredicates = parameterAsEnums( parameters, QStringLiteral( "PREDICATE" ), context );
 
   QgsFeatureIds selectedIds;
-  auto addToSelection = [&]( const QgsFeature & feature )
-  {
+  auto addToSelection = [&]( const QgsFeature &feature ) {
     selectedIds.insert( feature.id() );
   };
 
@@ -456,7 +423,7 @@ QVariantMap QgsSelectByLocationAlgorithm::processAlgorithm( const QVariantMap &p
     case Qgis::SelectBehavior::RemoveFromSelection:
     {
       // When subsetting or removing we only need to check already selected features
-      std::unique_ptr< QgsVectorLayerSelectedFeatureSource > selectLayerSelected( new QgsVectorLayerSelectedFeatureSource( selectLayer ) );
+      auto selectLayerSelected = std::make_unique<QgsVectorLayerSelectedFeatureSource>( selectLayer );
       mTargetCrs = selectLayerSelected->sourceCrs();
       mTargetFeatureCount = selectLayerSelected->featureCount();
       process( context, selectLayerSelected.get(), intersectSource.get(), selectedPredicates, addToSelection, true, feedback );
@@ -484,13 +451,9 @@ QVariantMap QgsSelectByLocationAlgorithm::processAlgorithm( const QVariantMap &p
 
 void QgsExtractByLocationAlgorithm::initAlgorithm( const QVariantMap & )
 {
-  addParameter( new QgsProcessingParameterFeatureSource( QStringLiteral( "INPUT" ),
-                QObject::tr( "Extract features from" ),
-                QList< int >() << static_cast< int >( Qgis::ProcessingSourceType::VectorAnyGeometry ) ) );
+  addParameter( new QgsProcessingParameterFeatureSource( QStringLiteral( "INPUT" ), QObject::tr( "Extract features from" ), QList<int>() << static_cast<int>( Qgis::ProcessingSourceType::VectorAnyGeometry ) ) );
   addPredicateParameter();
-  addParameter( new QgsProcessingParameterFeatureSource( QStringLiteral( "INTERSECT" ),
-                QObject::tr( "By comparing to the features from" ),
-                QList< int >() << static_cast< int >( Qgis::ProcessingSourceType::VectorAnyGeometry ) ) );
+  addParameter( new QgsProcessingParameterFeatureSource( QStringLiteral( "INTERSECT" ), QObject::tr( "By comparing to the features from" ), QList<int>() << static_cast<int>( Qgis::ProcessingSourceType::VectorAnyGeometry ) ) );
 
   addParameter( new QgsProcessingParameterFeatureSink( QStringLiteral( "OUTPUT" ), QObject::tr( "Extracted (location)" ) ) );
 }
@@ -534,11 +497,10 @@ QgsExtractByLocationAlgorithm *QgsExtractByLocationAlgorithm::createInstance() c
 
 bool QgsExtractByLocationAlgorithm::prepareAlgorithm( const QVariantMap &parameters, QgsProcessingContext &context, QgsProcessingFeedback * )
 {
-
-  std::unique_ptr< QgsFeatureSource > input( parameterAsSource( parameters, QStringLiteral( "INPUT" ), context ) );
+  std::unique_ptr<QgsFeatureSource> input( parameterAsSource( parameters, QStringLiteral( "INPUT" ), context ) );
   if ( !input )
     throw QgsProcessingException( invalidSourceError( parameters, QStringLiteral( "INPUT" ) ) );
-  std::unique_ptr< QgsFeatureSource > intersectSource( parameterAsSource( parameters, QStringLiteral( "INTERSECT" ), context ) );
+  std::unique_ptr<QgsFeatureSource> intersectSource( parameterAsSource( parameters, QStringLiteral( "INTERSECT" ), context ) );
   if ( !intersectSource )
     throw QgsProcessingException( invalidSourceError( parameters, QStringLiteral( "INTERSECT" ) ) );
 
@@ -551,33 +513,32 @@ bool QgsExtractByLocationAlgorithm::prepareAlgorithm( const QVariantMap &paramet
 
 QVariantMap QgsExtractByLocationAlgorithm::processAlgorithm( const QVariantMap &parameters, QgsProcessingContext &context, QgsProcessingFeedback *feedback )
 {
-  std::unique_ptr< QgsFeatureSource > input( parameterAsSource( parameters, QStringLiteral( "INPUT" ), context ) );
+  std::unique_ptr<QgsFeatureSource> input( parameterAsSource( parameters, QStringLiteral( "INPUT" ), context ) );
   if ( !input )
     throw QgsProcessingException( invalidSourceError( parameters, QStringLiteral( "INPUT" ) ) );
-  std::unique_ptr< QgsFeatureSource > intersectSource( parameterAsSource( parameters, QStringLiteral( "INTERSECT" ), context ) );
+  std::unique_ptr<QgsFeatureSource> intersectSource( parameterAsSource( parameters, QStringLiteral( "INTERSECT" ), context ) );
   if ( !intersectSource )
     throw QgsProcessingException( invalidSourceError( parameters, QStringLiteral( "INTERSECT" ) ) );
 
-  const QList< int > selectedPredicates = parameterAsEnums( parameters, QStringLiteral( "PREDICATE" ), context );
+  const QList<int> selectedPredicates = parameterAsEnums( parameters, QStringLiteral( "PREDICATE" ), context );
   QString dest;
-  std::unique_ptr< QgsFeatureSink > sink( parameterAsSink( parameters, QStringLiteral( "OUTPUT" ), context, dest, input->fields(), input->wkbType(), mTargetCrs ) );
+  std::unique_ptr<QgsFeatureSink> sink( parameterAsSink( parameters, QStringLiteral( "OUTPUT" ), context, dest, input->fields(), input->wkbType(), mTargetCrs ) );
 
   if ( !sink )
     throw QgsProcessingException( invalidSinkError( parameters, QStringLiteral( "OUTPUT" ) ) );
 
-  auto addToSink = [&]( const QgsFeature & feature )
-  {
+  auto addToSink = [&]( const QgsFeature &feature ) {
     QgsFeature f = feature;
     if ( !sink->addFeature( f, QgsFeatureSink::FastInsert ) )
       throw QgsProcessingException( writeFeatureError( sink.get(), parameters, QStringLiteral( "OUTPUT" ) ) );
   };
   process( context, input.get(), intersectSource.get(), selectedPredicates, addToSink, false, feedback );
 
+  sink->finalize();
+
   QVariantMap results;
   results.insert( QStringLiteral( "OUTPUT" ), dest );
   return results;
 }
 
 ///@endcond
-
-
