@@ -55,9 +55,10 @@
 #include "qgsmapcanvasutils.h"
 #include "qgsmaplayeraction.h"
 #include "qgsvectortilelayer.h"
-#include "qgsvectortiledataprovider.h"
 #include "qgsproviderregistry.h"
 #include "qgsprovidermetadata.h"
+#include "qgsrasterlabeling.h"
+#include "qgssymbollayerutils.h"
 
 QgsAppLayerTreeViewMenuProvider::QgsAppLayerTreeViewMenuProvider( QgsLayerTreeView *view, QgsMapCanvas *canvas )
   : mView( view )
@@ -156,7 +157,7 @@ QMenu *QgsAppLayerTreeViewMenuProvider::createContextMenu()
     }
     else if ( QgsLayerTree::isLayer( node ) )
     {
-      QgsMapLayer *layer = QgsLayerTree::toLayer( node )->layer();
+      QPointer<QgsMapLayer> layer { QgsLayerTree::toLayer( node )->layer() };
       QgsRasterLayer *rlayer = qobject_cast<QgsRasterLayer *>( layer );
       QgsVectorLayer *vlayer = qobject_cast<QgsVectorLayer *>( layer );
       QgsPointCloudLayer *pcLayer = qobject_cast<QgsPointCloudLayer *>( layer );
@@ -197,7 +198,7 @@ QMenu *QgsAppLayerTreeViewMenuProvider::createContextMenu()
         showFeatureCount->setEnabled( vlayer->isValid() );
       }
 
-      if ( vlayer || vectorTileLayer || meshLayer )
+      if ( vlayer || vectorTileLayer || meshLayer || rlayer )
       {
         const QString iconName = vectorTileLayer || ( vlayer && vlayer->labeling() && vlayer->labeling()->type() == QLatin1String( "rule-based" ) )
                                    ? QStringLiteral( "labelingRuleBased.svg" )
@@ -205,6 +206,7 @@ QMenu *QgsAppLayerTreeViewMenuProvider::createContextMenu()
         QAction *actionShowLabels = new QAction( QgsApplication::getThemeIcon( iconName ), tr( "Show &Labels" ), menu );
         actionShowLabels->setCheckable( true );
         actionShowLabels->setChecked( vectorTileLayer ? vectorTileLayer->labelsEnabled() : meshLayer ? meshLayer->labelsEnabled()
+                                                                                         : rlayer    ? rlayer->labelsEnabled()
                                                                                                      : vlayer->labelsEnabled() );
         connect( actionShowLabels, &QAction::toggled, this, &QgsAppLayerTreeViewMenuProvider::toggleLabels );
         menu->addAction( actionShowLabels );
@@ -241,64 +243,105 @@ QMenu *QgsAppLayerTreeViewMenuProvider::createContextMenu()
       }
 
       // No raster support in createSqlVectorLayer (yet)
-      if ( vlayer && vlayer->isSqlQuery() )
+      if ( vlayer )
       {
         const std::unique_ptr<QgsAbstractDatabaseProviderConnection> conn { QgsMapLayerUtils::databaseConnection( layer ) };
         if ( conn )
-          menu->addAction( QgsApplication::getThemeIcon( QStringLiteral( "/dbmanager.svg" ) ), tr( "Update SQL Layer…" ), menu, [layer, this] {
-            std::unique_ptr<QgsAbstractDatabaseProviderConnection> conn2 { QgsMapLayerUtils::databaseConnection( layer ) };
-            if ( conn2 )
-            {
-              QgsDialog dialog;
-              dialog.setObjectName( QStringLiteral( "SqlUpdateDialog" ) );
-              dialog.setWindowTitle( tr( "%1 — Update SQL" ).arg( layer->name() ) );
-              QgsGui::enableAutoGeometryRestore( &dialog );
-              QgsAbstractDatabaseProviderConnection::SqlVectorLayerOptions options { conn2->sqlOptions( layer->source() ) };
-              options.layerName = layer->name();
-              QgsQueryResultWidget *queryResultWidget { new QgsQueryResultWidget( &dialog, conn2.release() ) };
-              queryResultWidget->setWidgetMode( QgsQueryResultWidget::QueryWidgetMode::QueryLayerUpdateMode );
-              queryResultWidget->setSqlVectorLayerOptions( options );
-              queryResultWidget->executeQuery();
-              queryResultWidget->layout()->setContentsMargins( 0, 0, 0, 0 );
-              dialog.layout()->addWidget( queryResultWidget );
+        {
+          if ( vlayer->isSqlQuery() )
+            menu->addAction( QgsApplication::getThemeIcon( QStringLiteral( "/dbmanager.svg" ) ), tr( "Update SQL Layer…" ), menu, [layer, this] {
+              std::unique_ptr<QgsAbstractDatabaseProviderConnection> conn2 { QgsMapLayerUtils::databaseConnection( layer ) };
+              if ( conn2 )
+              {
+                QgsDialog dialog;
+                dialog.setObjectName( QStringLiteral( "SqlUpdateDialog" ) );
+                dialog.setWindowTitle( tr( "%1 — Update SQL" ).arg( layer->name() ) );
+                QgsGui::enableAutoGeometryRestore( &dialog );
+                QgsAbstractDatabaseProviderConnection::SqlVectorLayerOptions options { conn2->sqlOptions( layer->source() ) };
+                options.layerName = layer->name();
+                QgsQueryResultWidget *queryResultWidget { new QgsQueryResultWidget( &dialog, conn2.release() ) };
+                queryResultWidget->setWidgetMode( QgsQueryResultWidget::QueryWidgetMode::QueryLayerUpdateMode );
+                queryResultWidget->setSqlVectorLayerOptions( options );
+                queryResultWidget->executeQuery();
+                queryResultWidget->layout()->setContentsMargins( 0, 0, 0, 0 );
+                dialog.layout()->addWidget( queryResultWidget );
 
-              connect( queryResultWidget, &QgsQueryResultWidget::createSqlVectorLayer, queryResultWidget, [queryResultWidget, layer, this]( const QString &, const QString &, const QgsAbstractDatabaseProviderConnection::SqlVectorLayerOptions &options ) {
-                ( void ) this;
-                std::unique_ptr<QgsAbstractDatabaseProviderConnection> conn3 { QgsMapLayerUtils::databaseConnection( layer ) };
-                if ( conn3 )
-                {
-                  try
+                connect( queryResultWidget, &QgsQueryResultWidget::createSqlVectorLayer, queryResultWidget, [queryResultWidget, layer, this]( const QString &, const QString &, const QgsAbstractDatabaseProviderConnection::SqlVectorLayerOptions &options ) {
+                  ( void ) this;
+                  std::unique_ptr<QgsAbstractDatabaseProviderConnection> conn3 { QgsMapLayerUtils::databaseConnection( layer ) };
+                  if ( conn3 )
                   {
-                    std::unique_ptr<QgsMapLayer> sqlLayer { conn3->createSqlVectorLayer( options ) };
-                    if ( sqlLayer->isValid() )
+                    try
                     {
-                      layer->setDataSource( sqlLayer->source(), sqlLayer->name(), sqlLayer->dataProvider()->name(), QgsDataProvider::ProviderOptions() );
-                      queryResultWidget->notify( QObject::tr( "Layer Update Success" ), QObject::tr( "The SQL layer was updated successfully" ), Qgis::MessageLevel::Success );
-                    }
-                    else
-                    {
-                      QString error { sqlLayer->dataProvider()->error().message( QgsErrorMessage::Format::Text ) };
-                      if ( error.isEmpty() )
+                      std::unique_ptr<QgsMapLayer> sqlLayer { conn3->createSqlVectorLayer( options ) };
+                      if ( sqlLayer->isValid() )
                       {
-                        error = QObject::tr( "layer is not valid, check the log messages for more information" );
+                        layer->setDataSource( sqlLayer->source(), sqlLayer->name(), sqlLayer->dataProvider()->name(), QgsDataProvider::ProviderOptions() );
+                        queryResultWidget->notify( QObject::tr( "Layer Update Success" ), QObject::tr( "The SQL layer was updated successfully" ), Qgis::MessageLevel::Success );
                       }
-                      queryResultWidget->notify( QObject::tr( "Layer Update Error" ), QObject::tr( "Error updating the SQL layer: %1" ).arg( error ), Qgis::MessageLevel::Critical );
+                      else
+                      {
+                        QString error { sqlLayer->dataProvider()->error().message( QgsErrorMessage::Format::Text ) };
+                        if ( error.isEmpty() )
+                        {
+                          error = QObject::tr( "layer is not valid, check the log messages for more information" );
+                        }
+                        queryResultWidget->notify( QObject::tr( "Layer Update Error" ), QObject::tr( "Error updating the SQL layer: %1" ).arg( error ), Qgis::MessageLevel::Critical );
+                      }
+                    }
+                    catch ( QgsProviderConnectionException &ex )
+                    {
+                      queryResultWidget->notify( QObject::tr( "Layer Update Error" ), QObject::tr( "Error updating the SQL layer: %1" ).arg( ex.what() ), Qgis::MessageLevel::Critical );
                     }
                   }
-                  catch ( QgsProviderConnectionException &ex )
-                  {
-                    queryResultWidget->notify( QObject::tr( "Layer Update Error" ), QObject::tr( "Error updating the SQL layer: %1" ).arg( ex.what() ), Qgis::MessageLevel::Critical );
-                  }
-                }
-              } );
+                } );
 
-              dialog.exec();
-            }
-          } );
+                dialog.exec();
+              }
+            } );
+
+          // SQL dialog
+          if ( conn->capabilities().testFlag( QgsAbstractDatabaseProviderConnection::Capability::ExecuteSql ) )
+            menu->addAction( QgsApplication::getThemeIcon( QStringLiteral( "/dbmanager.svg" ) ), tr( "Execute SQL…" ), menu, [layer, this] {
+              std::unique_ptr<QgsAbstractDatabaseProviderConnection> conn2 { QgsMapLayerUtils::databaseConnection( layer ) };
+              if ( conn2 )
+              {
+                QgsDialog dialog;
+                dialog.setObjectName( QStringLiteral( "SqlExecuteDialog" ) );
+                dialog.setWindowTitle( tr( "Execute SQL" ) );
+                QgsGui::enableAutoGeometryRestore( &dialog );
+                QgsAbstractDatabaseProviderConnection::SqlVectorLayerOptions options { conn2->sqlOptions( layer->source() ) };
+                QgsQueryResultWidget *queryResultWidget { new QgsQueryResultWidget( &dialog, conn2.release() ) };
+                queryResultWidget->setSqlVectorLayerOptions( options );
+                queryResultWidget->executeQuery();
+                queryResultWidget->layout()->setContentsMargins( 0, 0, 0, 0 );
+                dialog.layout()->addWidget( queryResultWidget );
+
+                connect( queryResultWidget, &QgsQueryResultWidget::createSqlVectorLayer, queryResultWidget, [queryResultWidget, layer, this]( const QString &, const QString &, const QgsAbstractDatabaseProviderConnection::SqlVectorLayerOptions &options ) {
+                  ( void ) this;
+                  std::unique_ptr<QgsAbstractDatabaseProviderConnection> conn3 { QgsMapLayerUtils::databaseConnection( layer ) };
+                  if ( conn3 )
+                  {
+                    try
+                    {
+                      QgsMapLayer *sqlLayer { conn3->createSqlVectorLayer( options ) };
+                      QgsProject::instance()->addMapLayers( { sqlLayer } );
+                    }
+                    catch ( QgsProviderConnectionException &ex )
+                    {
+                      queryResultWidget->notify( QObject::tr( "New SQL Layer Creation Error" ), QObject::tr( "Error creating the SQL layer: %1" ).arg( ex.what() ), Qgis::MessageLevel::Critical );
+                    }
+                  }
+                } );
+
+                dialog.exec();
+              }
+            } );
+        }
       }
 
       addCustomLayerActions( menu, layer );
-      if ( layer && layer->type() == Qgis::LayerType::Vector && static_cast<QgsVectorLayer *>( layer )->providerType() == QLatin1String( "virtual" ) )
+      if ( layer && vlayer && vlayer->providerType() == QLatin1String( "virtual" ) )
       {
         menu->addAction( QgsApplication::getThemeIcon( QStringLiteral( "/mActionAddVirtualLayer.svg" ) ), tr( "Edit Virtual Layer…" ), QgisApp::instance(), &QgisApp::addVirtualLayer );
       }
@@ -334,7 +377,7 @@ QMenu *QgsAppLayerTreeViewMenuProvider::createContextMenu()
 
       menu->addSeparator();
 
-      if ( vlayer || meshLayer )
+      if ( vlayer || meshLayer || pcLayer )
       {
         QAction *toggleEditingAction = QgisApp::instance()->actionToggleEditing();
         QAction *saveLayerEditsAction = QgisApp::instance()->actionSaveActiveLayerEdits();
@@ -367,17 +410,12 @@ QMenu *QgsAppLayerTreeViewMenuProvider::createContextMenu()
 
         if ( allEditsAction->isEnabled() )
           menu->addAction( allEditsAction );
-
-        if ( vlayer && vlayer->dataProvider() && vlayer->dataProvider()->supportsSubsetString() )
-        {
-          QAction *action = menu->addAction( tr( "&Filter…" ), QgisApp::instance(), qOverload<>( &QgisApp::layerSubsetString ) );
-          action->setEnabled( !vlayer->isEditable() );
-        }
       }
 
-      if ( ( rlayer && rlayer->dataProvider() && rlayer->dataProvider()->supportsSubsetString() ) || ( pcLayer && pcLayer->dataProvider() && pcLayer->dataProvider()->supportsSubsetString() ) )
+      if ( layer && layer->dataProvider() && layer->dataProvider()->supportsSubsetString() )
       {
-        menu->addAction( tr( "&Filter…" ), QgisApp::instance(), qOverload<>( &QgisApp::layerSubsetString ) );
+        QAction *action = menu->addAction( tr( "&Filter…" ), QgisApp::instance(), qOverload<>( &QgisApp::layerSubsetString ) );
+        action->setEnabled( !layer->isEditable() );
       }
 
       // change data source is only supported for vectors, rasters, point clouds, mesh, some vector tile layers
@@ -1147,6 +1185,7 @@ void QgsAppLayerTreeViewMenuProvider::pasteVectorSymbol( const QString &layerId
       originalSymbol = embeddedRenderer->symbol();
   }
   std::unique_ptr<QgsSymbol> tempSymbol( QgsSymbolLayerUtils::symbolFromMimeData( QApplication::clipboard()->mimeData() ) );
+  QgsSymbolLayerUtils::resetSymbolLayerIds( tempSymbol.get() );
   if ( !tempSymbol )
     return;
 
@@ -1274,6 +1313,7 @@ void QgsAppLayerTreeViewMenuProvider::pasteSymbolLegendNodeSymbol( const QString
   QgsVectorLayer *vlayer = qobject_cast<QgsVectorLayer *>( node->layerNode()->layer() );
 
   std::unique_ptr<QgsSymbol> tempSymbol( QgsSymbolLayerUtils::symbolFromMimeData( QApplication::clipboard()->mimeData() ) );
+  QgsSymbolLayerUtils::resetSymbolLayerIds( tempSymbol.get() );
   if ( tempSymbol && tempSymbol->type() == originalSymbol->type() )
   {
     node->setSymbol( tempSymbol.release() );
@@ -1378,5 +1418,21 @@ void QgsAppLayerTreeViewMenuProvider::toggleLabels( bool enabled )
       meshLayer->emitStyleChanged();
       meshLayer->triggerRepaint();
     }
+    else if ( QgsRasterLayer *rasterLayer = qobject_cast<QgsRasterLayer *>( l->layer() ) )
+    {
+      if ( enabled && !rasterLayer->labeling() )
+      {
+        // no labeling setup - create default labeling for layer
+        rasterLayer->setLabeling( QgsAbstractRasterLayerLabeling::defaultLabelingForLayer( rasterLayer ) );
+        rasterLayer->setLabelsEnabled( true );
+      }
+      else
+      {
+        rasterLayer->setLabelsEnabled( enabled );
+      }
+
+      rasterLayer->emitStyleChanged();
+      rasterLayer->triggerRepaint();
+    }
   }
 }
