@@ -26,6 +26,7 @@
 #include <QUrl>
 
 #include "qgsmapsavedialog.h"
+#include "moc_qgsmapsavedialog.cpp"
 #include "qgsabstractgeopdfexporter.h"
 #include "qgsguiutils.h"
 #include "qgis.h"
@@ -47,7 +48,7 @@
 #include "qgsfileutils.h"
 #include "qgsannotationlayer.h"
 
-QgsMapSaveDialog::QgsMapSaveDialog( QWidget *parent, QgsMapCanvas *mapCanvas, const QList<QgsMapDecoration *> &decorations, const QList< QgsAnnotation *> &annotations, DialogType type )
+QgsMapSaveDialog::QgsMapSaveDialog( QWidget *parent, QgsMapCanvas *mapCanvas, const QList<QgsMapDecoration *> &decorations, const QList<QgsAnnotation *> &annotations, DialogType type )
   : QDialog( parent )
   , mDialogType( type )
   , mMapCanvas( mapCanvas )
@@ -64,7 +65,7 @@ QgsMapSaveDialog::QgsMapSaveDialog( QWidget *parent, QgsMapCanvas *mapCanvas, co
   mSize = ms.outputSize();
   mDevicePixelRatio = ms.devicePixelRatio();
 
-  mResolutionSpinBox->setValue( static_cast< int >( std::round( mDpi ) ) );
+  mResolutionSpinBox->setValue( static_cast<int>( std::round( mDpi ) ) );
 
   mExtentGroupBox->setOutputCrs( ms.destinationCrs() );
   mExtentGroupBox->setCurrentExtent( mExtent, ms.destinationCrs() );
@@ -86,9 +87,9 @@ QgsMapSaveDialog::QgsMapSaveDialog( QWidget *parent, QgsMapCanvas *mapCanvas, co
   }
   mDrawDecorations->setText( tr( "Draw active decorations: %1" ).arg( !activeDecorations.isEmpty() ? activeDecorations : tr( "none" ) ) );
 
-  connect( mResolutionSpinBox, &QSpinBox::editingFinished, this, [ = ] { updateDpi( mResolutionSpinBox->value() ); } );
-  connect( mOutputWidthSpinBox, &QSpinBox::editingFinished, this, [ = ] { updateOutputWidth( mOutputWidthSpinBox->value() );} );
-  connect( mOutputHeightSpinBox, &QSpinBox::editingFinished, this, [ = ] { updateOutputHeight( mOutputHeightSpinBox->value() );} );
+  connect( mResolutionSpinBox, &QSpinBox::editingFinished, this, [=] { updateDpi( mResolutionSpinBox->value() ); } );
+  connect( mOutputWidthSpinBox, &QSpinBox::editingFinished, this, [=] { updateOutputWidth( mOutputWidthSpinBox->value() ); } );
+  connect( mOutputHeightSpinBox, &QSpinBox::editingFinished, this, [=] { updateOutputHeight( mOutputHeightSpinBox->value() ); } );
   connect( mExtentGroupBox, &QgsExtentGroupBox::extentChanged, this, &QgsMapSaveDialog::updateExtent );
   connect( mScaleWidget, &QgsScaleWidget::scaleChanged, this, &QgsMapSaveDialog::updateScale );
   connect( mLockAspectRatio, &QgsRatioLockButton::lockChanged, this, &QgsMapSaveDialog::lockChanged );
@@ -99,8 +100,7 @@ QgsMapSaveDialog::QgsMapSaveDialog( QWidget *parent, QgsMapCanvas *mapCanvas, co
   {
     case Pdf:
     {
-      connect( mInfo, &QLabel::linkActivated, this, [this]( const QString & )
-      {
+      connect( mInfo, &QLabel::linkActivated, this, [this]( const QString & ) {
         QgsMessageViewer *viewer = new QgsMessageViewer( this );
         viewer->setWindowTitle( tr( "Advanced effects warning" ) );
         viewer->setMessageAsPlainText( mInfoDetails );
@@ -109,9 +109,9 @@ QgsMapSaveDialog::QgsMapSaveDialog( QWidget *parent, QgsMapCanvas *mapCanvas, co
 
       this->setWindowTitle( tr( "Save Map as PDF" ) );
 
-      mTextRenderFormatComboBox->addItem( tr( "Always Export Text as Paths (Recommended)" ), static_cast< int>( Qgis::TextRenderFormat::AlwaysOutlines ) );
-      mTextRenderFormatComboBox->addItem( tr( "Always Export Text as Text Objects" ), static_cast< int >( Qgis::TextRenderFormat::AlwaysText ) );
-      mTextRenderFormatComboBox->addItem( tr( "Prefer Exporting Text as Text Objects" ), static_cast< int >( Qgis::TextRenderFormat::PreferText ) );
+      mTextRenderFormatComboBox->addItem( tr( "Always Export Text as Paths (Recommended)" ), static_cast<int>( Qgis::TextRenderFormat::AlwaysOutlines ) );
+      mTextRenderFormatComboBox->addItem( tr( "Always Export Text as Text Objects" ), static_cast<int>( Qgis::TextRenderFormat::AlwaysText ) );
+      mTextRenderFormatComboBox->addItem( tr( "Prefer Exporting Text as Text Objects" ), static_cast<int>( Qgis::TextRenderFormat::PreferText ) );
 
       const bool geospatialPdfAvailable = QgsAbstractGeospatialPdfExporter::geospatialPDFCreationAvailable();
       mGeospatialPDFGroupBox->setEnabled( geospatialPdfAvailable );
@@ -129,8 +129,6 @@ QgsMapSaveDialog::QgsMapSaveDialog( QWidget *parent, QgsMapCanvas *mapCanvas, co
       else
       {
         mGeospatialPDFOptionsStackedWidget->setCurrentIndex( 1 );
-        mGeospatialPdfFormatComboBox->addItem( tr( "ISO 32000 Extension (recommended)" ) );
-        mGeospatialPdfFormatComboBox->addItem( tr( "OGC Best Practice" ) );
       }
 
       connect( mGeospatialPDFGroupBox, &QGroupBox::toggled, this, &QgsMapSaveDialog::updatePdfExportWarning );
@@ -232,7 +230,7 @@ void QgsMapSaveDialog::updateExtent( const QgsRectangle &extent )
 
     QgsMapSettings ms = mMapCanvas->mapSettings();
     ms.setRotation( 0 );
-    mDpi = static_cast< int>( std::round( ms.outputDpi() ) ) ;
+    mDpi = static_cast<int>( std::round( ms.outputDpi() ) );
     mSize.setWidth( ms.outputSize().width() * extent.width() / ms.visibleExtent().width() );
     mSize.setHeight( ms.outputSize().height() * extent.height() / ms.visibleExtent().height() );
 
@@ -332,7 +330,7 @@ void QgsMapSaveDialog::applyMapSettings( QgsMapSettings &mapSettings )
   switch ( mDialogType )
   {
     case Pdf:
-      mapSettings.setFlag( Qgis::MapSettingsFlag::Antialiasing, true ); // hardcode antialiasing when saving as PDF
+      mapSettings.setFlag( Qgis::MapSettingsFlag::Antialiasing, true );               // hardcode antialiasing when saving as PDF
       mapSettings.setFlag( Qgis::MapSettingsFlag::HighQualityImageTransforms, true ); // hardcode antialiasing when saving as PDF
       break;
 
@@ -355,7 +353,7 @@ void QgsMapSaveDialog::applyMapSettings( QgsMapSettings &mapSettings )
   mapSettings.setRotation( mMapCanvas->rotation() );
   mapSettings.setEllipsoid( QgsProject::instance()->ellipsoid() );
 
-  QList< QgsMapLayer * > layers = mMapCanvas->layers();
+  QList<QgsMapLayer *> layers = mMapCanvas->layers();
   if ( !QgsProject::instance()->mainAnnotationLayer()->isEmpty() )
   {
     layers.insert( 0, QgsProject::instance()->mainAnnotationLayer() );
@@ -425,8 +423,7 @@ void QgsMapSaveDialog::copyToClipboard()
     mapRendererTask->addDecorations( mDecorations );
   }
 
-  connect( mapRendererTask, &QgsMapRendererTask::renderingComplete, this, [ = ]
-  {
+  connect( mapRendererTask, &QgsMapRendererTask::renderingComplete, this, [=] {
     QApplication::clipboard()->setImage( *img, QClipboard::Clipboard );
     QApplication::restoreOverrideCursor();
     QgisApp::instance()->messageBar()->pushSuccess( tr( "Save as image" ), tr( "Successfully copied map to clipboard" ) );
@@ -435,8 +432,7 @@ void QgsMapSaveDialog::copyToClipboard()
     delete img;
     setEnabled( true );
   } );
-  connect( mapRendererTask, &QgsMapRendererTask::errorOccurred, this, [ = ]( int )
-  {
+  connect( mapRendererTask, &QgsMapRendererTask::errorOccurred, this, [=]( int ) {
     QApplication::restoreOverrideCursor();
     QgisApp::instance()->messageBar()->pushWarning( tr( "Save as image" ), tr( "Could not copy the map to clipboard" ) );
 
@@ -457,7 +453,7 @@ void QgsMapSaveDialog::onAccepted()
   {
     case Image:
     {
-      const QPair< QString, QString> fileNameAndFilter = QgsGuiUtils::getSaveAsImageName( QgisApp::instance(), tr( "Choose a file name to save the map image as" ) );
+      const QPair<QString, QString> fileNameAndFilter = QgsGuiUtils::getSaveAsImageName( QgisApp::instance(), tr( "Choose a file name to save the map image as" ) );
       if ( !fileNameAndFilter.first.isEmpty() )
       {
         QgsMapSettings ms = QgsMapSettings();
@@ -477,13 +473,10 @@ void QgsMapSaveDialog::onAccepted()
 
         mapRendererTask->setSaveWorldFile( saveWorldFile() );
 
-        connect( mapRendererTask, &QgsMapRendererTask::renderingComplete, [ = ]
-        {
-          QgisApp::instance()->messageBar()->pushSuccess( tr( "Save as image" ), tr( "Successfully saved map to <a href=\"%1\">%2</a>" )
-              .arg( QUrl::fromLocalFile( fileNameAndFilter.first ).toString(), QDir::toNativeSeparators( fileNameAndFilter.first ) ) );
+        connect( mapRendererTask, &QgsMapRendererTask::renderingComplete, [=] {
+          QgisApp::instance()->messageBar()->pushSuccess( tr( "Save as image" ), tr( "Successfully saved map to <a href=\"%1\">%2</a>" ).arg( QUrl::fromLocalFile( fileNameAndFilter.first ).toString(), QDir::toNativeSeparators( fileNameAndFilter.first ) ) );
         } );
-        connect( mapRendererTask, &QgsMapRendererTask::errorOccurred, [ = ]( int error )
-        {
+        connect( mapRendererTask, &QgsMapRendererTask::errorOccurred, [=]( int error ) {
           switch ( error )
           {
             case QgsMapRendererTask::ImageAllocationFail:
@@ -532,7 +525,7 @@ void QgsMapSaveDialog::onAccepted()
           ms.setSimplifyMethod( simplifyMethod );
         }
 
-        ms.setTextRenderFormat( static_cast< Qgis::TextRenderFormat >( mTextRenderFormatComboBox->currentData().toInt() ) );
+        ms.setTextRenderFormat( static_cast<Qgis::TextRenderFormat>( mTextRenderFormatComboBox->currentData().toInt() ) );
 
         QgsAbstractGeospatialPdfExporter::ExportDetails geospatialPdfExportDetails;
         if ( mExportMetadataCheckBox->isChecked() )
@@ -549,16 +542,7 @@ void QgsMapSaveDialog::onAccepted()
 
         if ( mGeospatialPDFGroupBox->isChecked() )
         {
-          if ( mGeospatialPdfFormatComboBox->currentIndex() == 0 )
-          {
-            geospatialPdfExportDetails.useIso32000ExtensionFormatGeoreferencing = true;
-            geospatialPdfExportDetails.useOgcBestPracticeFormatGeoreferencing = false;
-          }
-          else
-          {
-            geospatialPdfExportDetails.useIso32000ExtensionFormatGeoreferencing = false;
-            geospatialPdfExportDetails.useOgcBestPracticeFormatGeoreferencing = true;
-          }
+          geospatialPdfExportDetails.useIso32000ExtensionFormatGeoreferencing = true;
 
           geospatialPdfExportDetails.includeFeatures = mExportGeospatialPdfFeaturesCheckBox->isChecked();
         }
@@ -581,13 +565,10 @@ void QgsMapSaveDialog::onAccepted()
           mapRendererTask->setExportMetadata( exportMetadata() );
         }
 
-        connect( mapRendererTask, &QgsMapRendererTask::renderingComplete, [ = ]
-        {
-          QgisApp::instance()->messageBar()->pushSuccess( tr( "Save as PDF" ), tr( "Successfully saved map to <a href=\"%1\">%2</a>" )
-              .arg( QUrl::fromLocalFile( fileName ).toString(), QDir::toNativeSeparators( fileName ) ) );
+        connect( mapRendererTask, &QgsMapRendererTask::renderingComplete, [=] {
+          QgisApp::instance()->messageBar()->pushSuccess( tr( "Save as PDF" ), tr( "Successfully saved map to <a href=\"%1\">%2</a>" ).arg( QUrl::fromLocalFile( fileName ).toString(), QDir::toNativeSeparators( fileName ) ) );
         } );
-        connect( mapRendererTask, &QgsMapRendererTask::errorOccurred, [ = ]( int )
-        {
+        connect( mapRendererTask, &QgsMapRendererTask::errorOccurred, [=]( int ) {
           QgisApp::instance()->messageBar()->pushWarning( tr( "Save as PDF" ), tr( "Could not save the map to PDF" ) );
         } );
 
@@ -603,8 +584,7 @@ void QgsMapSaveDialog::updatePdfExportWarning()
   const QStringList layers = QgsMapSettingsUtils::containsAdvancedEffects( mMapCanvas->mapSettings(), mGeospatialPDFGroupBox->isChecked() ? QgsMapSettingsUtils::EffectsCheckFlags( QgsMapSettingsUtils::EffectsCheckFlag::IgnoreGeoPdfSupportedEffects ) : QgsMapSettingsUtils::EffectsCheckFlags() );
   if ( !layers.isEmpty() )
   {
-    mInfoDetails = tr( "The following layer(s) use advanced effects:\n\n%1\n\nRasterizing map is recommended for proper rendering." ).arg(
-                     QChar( 0x2022 ) + QStringLiteral( " " ) + layers.join( QStringLiteral( "\n" ) + QChar( 0x2022 ) + QStringLiteral( " " ) ) );
+    mInfoDetails = tr( "The following layer(s) use advanced effects:\n\n%1\n\nRasterizing map is recommended for proper rendering." ).arg( QChar( 0x2022 ) + QStringLiteral( " " ) + layers.join( QStringLiteral( "\n" ) + QChar( 0x2022 ) + QStringLiteral( " " ) ) );
     mInfo->setText( tr( "%1A number of layers%2 use advanced effects, rasterizing map is recommended for proper rendering." ).arg( QStringLiteral( "<a href='#'>" ), QStringLiteral( "</a>" ) ) );
     mSaveAsRaster->setChecked( true );
   }
