@@ -33,18 +33,16 @@
 #include "qgs3dmapsettings.h"
 #include "qgs3dmapscene.h"
 
-#include <QFileInfo>
-#include <QDir>
-
 class TestQgsPointCloud3DRendering : public QgsTest
 {
     Q_OBJECT
   public:
-    TestQgsPointCloud3DRendering() : QgsTest( QStringLiteral( "Point Cloud 3D Rendering Tests" ), QStringLiteral( "3d" ) ) {}
+    TestQgsPointCloud3DRendering()
+      : QgsTest( QStringLiteral( "Point Cloud 3D Rendering Tests" ), QStringLiteral( "3d" ) ) {}
 
   private slots:
-    void initTestCase();// will be called before the first testfunction is executed.
-    void cleanupTestCase();// will be called after the last testfunction was executed.
+    void initTestCase();    // will be called before the first testfunction is executed.
+    void cleanupTestCase(); // will be called after the last testfunction was executed.
     void testSync3DRendererTo2DRenderer();
     void testDisableSync3DRendererTo2DRenderer();
 
@@ -57,12 +55,14 @@ class TestQgsPointCloud3DRendering : public QgsTest
     void testPointCloudFilteredClassification();
     void testPointCloudFilteredSceneExtent();
 
+    void testPointCloud3DExtents();
+    void testPointCloud3DOverview();
+
 
   private:
-
     std::unique_ptr<QgsProject> mProject;
     QgsPointCloudLayer *mLayer;
-
+    QgsPointCloudLayer *mVpcLayer;
 };
 
 //runs before all tests
@@ -80,6 +80,9 @@ void TestQgsPointCloud3DRendering::initTestCase()
   mLayer = new QgsPointCloudLayer( dataDir + "/point_clouds/ept/sunshine-coast-laz/ept.json", "test", "ept" );
   QVERIFY( mLayer->isValid() );
   mProject->addMapLayer( mLayer );
+  mVpcLayer = new QgsPointCloudLayer( dataDir + "/point_clouds/virtual/sunshine-coast/combined-with-overview.vpc", "test", "vpc" );
+  QVERIFY( mVpcLayer->isValid() );
+  mProject->addMapLayer( mVpcLayer );
   mProject->setCrs( mLayer->crs() );
 
   // set a default 3D renderer
@@ -221,23 +224,23 @@ void TestQgsPointCloud3DRendering::testDisableSync3DRendererTo2DRenderer()
 
   {
     mLayer->setRenderer( colorramp2DRenderer );
-    QgsPointCloudLayer3DRenderer *r3D  = static_cast<QgsPointCloudLayer3DRenderer *>( mLayer->renderer3D() );
+    QgsPointCloudLayer3DRenderer *r3D = static_cast<QgsPointCloudLayer3DRenderer *>( mLayer->renderer3D() );
     QVERIFY( r3D );
-    const QgsColorRampPointCloud3DSymbol *s = dynamic_cast<const QgsColorRampPointCloud3DSymbol *>( r3D ->symbol() );
+    const QgsColorRampPointCloud3DSymbol *s = dynamic_cast<const QgsColorRampPointCloud3DSymbol *>( r3D->symbol() );
     QVERIFY( s );
   }
   {
     mLayer->setRenderer( rgb2DRenderer );
-    QgsPointCloudLayer3DRenderer *r3D  = static_cast<QgsPointCloudLayer3DRenderer *>( mLayer->renderer3D() );
+    QgsPointCloudLayer3DRenderer *r3D = static_cast<QgsPointCloudLayer3DRenderer *>( mLayer->renderer3D() );
     QVERIFY( r3D );
-    const QgsColorRampPointCloud3DSymbol *s = dynamic_cast<const QgsColorRampPointCloud3DSymbol *>( r3D ->symbol() );
+    const QgsColorRampPointCloud3DSymbol *s = dynamic_cast<const QgsColorRampPointCloud3DSymbol *>( r3D->symbol() );
     QVERIFY( s );
   }
   {
     mLayer->setRenderer( classification2DRenderer );
-    QgsPointCloudLayer3DRenderer *r3D  = static_cast<QgsPointCloudLayer3DRenderer *>( mLayer->renderer3D() );
+    QgsPointCloudLayer3DRenderer *r3D = static_cast<QgsPointCloudLayer3DRenderer *>( mLayer->renderer3D() );
     QVERIFY( r3D );
-    const QgsColorRampPointCloud3DSymbol *s = dynamic_cast<const QgsColorRampPointCloud3DSymbol *>( r3D ->symbol() );
+    const QgsColorRampPointCloud3DSymbol *s = dynamic_cast<const QgsColorRampPointCloud3DSymbol *>( r3D->symbol() );
     QVERIFY( s );
   }
 }
@@ -287,7 +290,7 @@ void TestQgsPointCloud3DRendering::testPointCloudSingleColorClipping()
   map->setLayers( QList<QgsMapLayer *>() << mLayer );
   QgsPointLightSettings defaultLight;
   defaultLight.setIntensity( 0.5 );
-  defaultLight.setPosition( QgsVector3D( 0, 1000, 0 ) );
+  defaultLight.setPosition( QgsVector3D( 0, 0, 1000 ) );
   map->setLightSources( { defaultLight.clone() } );
 
   QgsOffscreen3DEngine engine;
@@ -305,8 +308,8 @@ void TestQgsPointCloud3DRendering::testPointCloudSingleColorClipping()
   scene->cameraController()->resetView( 90 );
 
   QList<QVector4D> clipPlanesEquations = QList<QVector4D>()
-                                         << QVector4D( 0.866025, 0, 0.5, 1.0 )
-                                         << QVector4D( 0.5, 0, -0.866025, 0.5 );
+                                         << QVector4D( 0.866025, -0.5, 0, 1.0 )
+                                         << QVector4D( 0.5, 0.866025, 0, 0.5 );
   scene->enableClipping( clipPlanesEquations );
 
 
@@ -425,8 +428,8 @@ void TestQgsPointCloud3DRendering::testPointCloudClassificationOverridePointSize
   QgsClassificationPointCloud3DSymbol *symbol = new QgsClassificationPointCloud3DSymbol();
   symbol->setAttribute( QStringLiteral( "Classification" ) );
   auto categories = QgsPointCloudClassifiedRenderer::defaultCategories();
-  categories[ 2 ].setPointSize( 4 );
-  categories[ 5 ].setPointSize( 7 );
+  categories[2].setPointSize( 4 );
+  categories[5].setPointSize( 7 );
   symbol->setCategoriesList( categories );
   symbol->setPointSize( 10 );
 
@@ -479,16 +482,15 @@ void TestQgsPointCloud3DRendering::testPointCloudFilteredClassification()
   // find a better fix in the future.
   QImage img = Qgs3DUtils::captureSceneImage( engine, scene );
 
-  QGSVERIFYIMAGECHECK( "pointcloud_3d_filtered_classification", "pointcloud_3d_filtered_classification", img, QString(), 80, QSize( 0, 0 ), 15 );
-
   mLayer->setSubsetString( "" );
+
+  QGSVERIFYIMAGECHECK( "pointcloud_3d_filtered_classification", "pointcloud_3d_filtered_classification", img, QString(), 80, QSize( 0, 0 ), 15 );
 }
 
 void TestQgsPointCloud3DRendering::testPointCloudFilteredSceneExtent()
 {
   const QgsRectangle fullExtent = mLayer->extent();
-  const QgsRectangle filteredExtent = QgsRectangle( fullExtent.xMinimum(), fullExtent.yMinimum(),
-                                      fullExtent.xMinimum() + fullExtent.width() / 3.0, fullExtent.yMinimum() + fullExtent.height() / 4.0 );
+  const QgsRectangle filteredExtent = QgsRectangle( fullExtent.xMinimum(), fullExtent.yMinimum(), fullExtent.xMinimum() + fullExtent.width() / 3.0, fullExtent.yMinimum() + fullExtent.height() / 4.0 );
 
   Qgs3DMapSettings *map = new Qgs3DMapSettings;
   map->setCrs( mProject->crs() );
@@ -524,5 +526,82 @@ void TestQgsPointCloud3DRendering::testPointCloudFilteredSceneExtent()
   QGSVERIFYIMAGECHECK( "pointcloud_3d_filtered_scene_extent", "pointcloud_3d_filtered_scene_extent", img, QString(), 80, QSize( 0, 0 ), 15 );
 }
 
+void TestQgsPointCloud3DRendering::testPointCloud3DExtents()
+{
+  mProject->setCrs( mVpcLayer->crs() );
+
+  Qgs3DMapSettings *map = new Qgs3DMapSettings;
+  map->setCrs( mProject->crs() );
+  map->setExtent( mVpcLayer->extent() );
+  map->setLayers( QList<QgsMapLayer *>() << mVpcLayer );
+  QgsPointLightSettings defaultLight;
+  defaultLight.setIntensity( 0.5 );
+  defaultLight.setPosition( QgsVector3D( 0, 1000, 0 ) );
+  map->setLightSources( { defaultLight.clone() } );
+
+  QgsOffscreen3DEngine engine;
+  Qgs3DMapScene *scene = new Qgs3DMapScene( *map, &engine );
+  engine.setRootEntity( scene );
+
+  QgsClassificationPointCloud3DSymbol *symbol = new QgsClassificationPointCloud3DSymbol();
+  symbol->setAttribute( QStringLiteral( "Classification" ) );
+  symbol->setCategoriesList( QgsPointCloudClassifiedRenderer::defaultCategories() );
+  symbol->setPointSize( 10 );
+
+  QgsPointCloudLayer3DRenderer *renderer = new QgsPointCloudLayer3DRenderer();
+  renderer->setSymbol( symbol );
+  mVpcLayer->setRenderer3D( renderer );
+
+  scene->cameraController()->resetView( 90 );
+  Qgs3DUtils::captureSceneImage( engine, scene );
+  // When running the test on Travis, it would initially return empty rendered image.
+  // Capturing the initial image and throwing it away fixes that. Hopefully we will
+  // find a better fix in the future.
+  const QImage img = Qgs3DUtils::captureSceneImage( engine, scene );
+
+  QGSVERIFYIMAGECHECK( "virtual_pointcloud_3d_extents", "virtual_pointcloud_3d_extents", img, QString(), 40, QSize( 0, 0 ), 55 );
+}
+
+void TestQgsPointCloud3DRendering::testPointCloud3DOverview()
+{
+  Qgs3DMapSettings *map = new Qgs3DMapSettings;
+  map->setCrs( mProject->crs() );
+  map->setExtent( mVpcLayer->extent() );
+  map->setLayers( QList<QgsMapLayer *>() << mVpcLayer );
+  QgsPointLightSettings defaultLight;
+  defaultLight.setIntensity( 0.5 );
+  defaultLight.setPosition( QgsVector3D( 0, 1000, 0 ) );
+  map->setLightSources( { defaultLight.clone() } );
+
+  QgsOffscreen3DEngine engine;
+  Qgs3DMapScene *scene = new Qgs3DMapScene( *map, &engine );
+  engine.setRootEntity( scene );
+
+  //Classification symbol
+  QgsClassificationPointCloud3DSymbol *symbol = new QgsClassificationPointCloud3DSymbol();
+  symbol->setAttribute( QStringLiteral( "Classification" ) );
+  symbol->setCategoriesList( QgsPointCloudClassifiedRenderer::defaultCategories() );
+  symbol->setPointSize( 3 );
+
+  mVpcLayer->setRenderer3D( nullptr );
+  QgsPointCloudLayer3DRenderer *renderer = new QgsPointCloudLayer3DRenderer();
+  renderer->setSymbol( symbol );
+  renderer->setZoomOutBehavior( Qgis::PointCloudZoomOutRenderBehavior::RenderOverview );
+  mVpcLayer->setRenderer3D( renderer );
+
+  scene->cameraController()->resetView( 120 );
+  Qgs3DUtils::captureSceneImage( engine, scene );
+  // There is a bug in overview rendering, which doesn't render overview right away, it needs to get out of camera view
+  // and back in. Then it renders correctly
+  scene->cameraController()->moveView( mVpcLayer->extent().width(), mVpcLayer->extent().height() );
+  scene->cameraController()->resetView( 120 );
+  // When running the test on Travis, it would initially return empty rendered image.
+  // Capturing the initial image and throwing it away fixes that. Hopefully we will
+  // find a better fix in the future.
+  const QImage img = Qgs3DUtils::captureSceneImage( engine, scene );
+
+  QGSVERIFYIMAGECHECK( "virtual_pointcloud_3d_overview", "virtual_pointcloud_3d_overview", img, QString(), 20, QSize( 0, 0 ), 15 );
+}
+
 QGSTEST_MAIN( TestQgsPointCloud3DRendering )
 #include "testqgspointcloud3drendering.moc"
