@@ -29,6 +29,7 @@ from qgis.core import (
     QgsLineSymbol,
     QgsMapSettings,
     QgsMarkerSymbol,
+    QgsMaskMarkerSymbolLayer,
     QgsProject,
     QgsProperty,
     QgsReadWriteContext,
@@ -36,9 +37,11 @@ from qgis.core import (
     QgsRenderContext,
     QgsRendererCategory,
     QgsSimpleMarkerSymbolLayer,
+    QgsSingleSymbolRenderer,
     QgsStyle,
     QgsSymbol,
     QgsSymbolLayer,
+    QgsSymbolLayerReference,
     QgsVectorLayer,
 )
 import unittest
@@ -815,6 +818,36 @@ class TestQgsCategorizedSymbolRenderer(QgisTestCase):
         self.assertEqual(cc.label(), "")
         self.assertEqual(cc.symbol().color().name(), "#ff00ff")
 
+    def testConvertNoMasks(self):
+        """
+        Test converting an embedded symbol renderer to a categorized renderer
+        """
+        points_layer = QgsVectorLayer("Point", "Polys", "memory")
+        f = QgsFeature()
+        f.setGeometry(QgsGeometry.fromWkt("Point(-100 30)"))
+        self.assertTrue(points_layer.dataProvider().addFeature(f))
+        f.setGeometry(QgsGeometry.fromWkt("Point(-110 40)"))
+        self.assertTrue(points_layer.dataProvider().addFeature(f))
+        f.setGeometry(QgsGeometry.fromWkt("Point(-90 50)"))
+        self.assertTrue(points_layer.dataProvider().addFeature(f))
+
+        p = QgsMarkerSymbol.createSimple({"color": "#fdbf6f", "size": "7"})
+        points_layer.setRenderer(QgsSingleSymbolRenderer(p))
+
+        circle_symbol = QgsMarkerSymbol.createSimple({"size": "10"})
+        mask_layer = QgsMaskMarkerSymbolLayer()
+        mask_layer.setSubSymbol(circle_symbol)
+        mask_layer.setMasks(
+            [QgsSymbolLayerReference("test_layer_id", "test_symbollayer_id")]
+        )
+        points_layer.renderer().symbol().appendSymbolLayer(mask_layer)
+
+        categorized = QgsCategorizedSymbolRenderer.convertFromRenderer(
+            points_layer.renderer(), points_layer
+        )
+
+        self.assertFalse(categorized.sourceSymbol().symbolLayers()[1].masks())
+
     def test_displayString(self):
         """Test the displayString method"""
 
@@ -1405,6 +1438,43 @@ class TestQgsCategorizedSymbolRenderer(QgisTestCase):
 """,
         )
 
+    def testMaximumExtentBuffer(self):
+        # setup renderer
+
+        fields = QgsFields()
+        fields.append(QgsField("x"))
+
+        renderer = QgsCategorizedSymbolRenderer()
+        renderer.setClassAttribute("x")
+
+        symbol_a = createMarkerSymbol()
+        symbol_a.setColor(QColor(255, 0, 0))
+        symbol_a.setExtentBuffer(10)
+        renderer.addCategory(QgsRendererCategory("a", symbol_a, "a"))
+
+        symbol_b = createMarkerSymbol()
+        symbol_b.setColor(QColor(0, 255, 0))
+        symbol_b.setExtentBuffer(-10)
+        renderer.addCategory(QgsRendererCategory("b", symbol_b, "b"))
+
+        symbol_c = createMarkerSymbol()
+        symbol_c.setColor(QColor(0, 0, 255))
+        symbol_c.setExtentBuffer(20)
+        renderer.addCategory(QgsRendererCategory("c", symbol_c, "c", False))
+
+        symbol_d = createMarkerSymbol()
+        symbol_d.setColor(QColor(255, 0, 255))
+        symbol_d.setExtentBuffer(15)
+        renderer.addCategory(QgsRendererCategory(["d", "e"], symbol_d, "de"))
+
+        # add default category
+
+        default_symbol = createMarkerSymbol()
+        default_symbol.setColor(QColor(255, 255, 255))
+        renderer.addCategory(QgsRendererCategory("", default_symbol, "default"))
+
+        self.assertEqual(renderer.maximumExtentBuffer(QgsRenderContext()), 20)
+
 
 if __name__ == "__main__":
     unittest.main()
